@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "bookmarkPlugin.h"
@@ -46,19 +46,19 @@ void bookmarkPlugin::parseBookmarks()
 {
     clear();
     const QString bmf(c2bUtils::fileToString(_bookmark_file));
-    QStringList bookmarks(bmf.split(QRegExp("[\\r\\n]"), _QT_6_KeepEmptyParts));
+    QStringList bookmarks(c2bUtils::split(bmf, QRegExp("[\\r\\n]"), _QT_6_KeepEmptyParts));
     const QRegExp _bookmark("^editorbookmark=");
     const QRegExp _separator("^editorbookmark=\\s*$");
     for (int i = 0; i < bookmarks.count(); ++i)
     {
-        if (bookmarks.at(i).contains(_separator))
+        if (_separator.indexIn(bookmarks.at(i)) >= 0)
         {
             addSeparator();
             continue;
         }
-        if (bookmarks.at(i).contains(_bookmark))
+        if (_bookmark.indexIn(bookmarks.at(i)) >= 0)
         {
-            bookmarks[i].remove(_bookmark);
+            c2bUtils::remove(bookmarks[i], _bookmark);
             const QStringList bm_parts(bookmarks.at(i).split('|', _QT_6_KeepEmptyParts));
             if (bm_parts.count() != 4)
             {
@@ -82,15 +82,15 @@ QString bookmarkPlugin::iconProvider(const QString& fn, const QString& iconFile)
 {
     if (!iconFile.isEmpty())
         return iconFile;
-    if (fn.contains(QRegExp("\\.(tex|dvi)\\b", Qt::CaseInsensitive)))
+    if (QRegExp("\\.(tex|dvi)\\b", Qt::CaseInsensitive).indexIn(fn) >= 0)
         return ":/icons/icons/application-x-tex.png";
-    if (fn.contains(QRegExp("\\.(chm|djvu|pdf|ps)\\b", Qt::CaseInsensitive)))
+    if (QRegExp("\\.(chm|djvu|pdf|ps)\\b", Qt::CaseInsensitive).indexIn(fn) >= 0)
         return ":/icons/icons/application-x-pdf.png";
-    if (fn.contains(QRegExp("\\.(htm|html|php)\\b", Qt::CaseInsensitive)))
+    if (QRegExp("\\.(htm|html|php)\\b", Qt::CaseInsensitive).indexIn(fn) >= 0)
         return ":/icons/icons/application-x-html.png";
-    if (fn.contains(QRegExp("\\.txt\\b", Qt::CaseInsensitive)))
+    if (QRegExp("\\.txt\\b", Qt::CaseInsensitive).indexIn(fn) >= 0)
         return ":/icons/icons/application-x-tex.png";
-    if (fn.contains(QRegExp("\\.bib\\b", Qt::CaseInsensitive)))
+    if (QRegExp("\\.bib\\b", Qt::CaseInsensitive).indexIn(fn) >= 0)
         return ":/icons/icons/cb2bib.png";
     return ":/icons/icons/application-x-none.png";
 }
