@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "arxivXml.h"
@@ -23,19 +23,19 @@ void arxivXml::readReference()
     QStringList authors;
 
     while (reading("entry"))
-        if (name() == "author")
+        if (name().toLatin1() == "author")
             appendAuthor(&authors);
-        else if (name() == "journal_ref")
+        else if (name().toLatin1() == "journal_ref")
             readField("note");
-        else if (name() == "title")
+        else if (name().toLatin1() == "title")
             readField("title");
-        else if (name() == "summary")
+        else if (name().toLatin1() == "summary")
             readField("abstract");
-        else if (name() == "doi")
+        else if (name().toLatin1() == "doi")
             readField("doi");
-        else if (name() == "id")
+        else if (name().toLatin1() == "id")
             processId();
-        else if (name() == "published")
+        else if (name().toLatin1() == "published")
             processDate();
 
     _reference["author"] = authors.join(", ");
@@ -51,10 +51,11 @@ void arxivXml::processId()
 {
     readNext();
     QRegExp rxarxiv("abs/(.+)$");
-    if (text().toString().contains(rxarxiv))
+    const int r(rxarxiv.indexIn(text().toString()));
+    if (r >= 0)
     {
         QString aid(rxarxiv.cap(1));
-        aid.remove(QRegExp("v\\d{1,2}$"));
+        c2bUtils::remove(aid, QRegExp("v\\d{1,2}$"));
         _reference["eprint"] = aid;
         _reference["journal"] = "arXiv:" + aid;
         _reference["url"] = c2bUtils::arxivUrl.arg(aid);
@@ -70,7 +71,7 @@ void arxivXml::processDate()
 void arxivXml::appendAuthor(QStringList* authors)
 {
     while (reading("name"))
-        if (name() == "name")
+        if (name().toLatin1() == "name")
         {
             readNext();
             authors->append(text().toString());
