@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "authorString.h"
@@ -44,20 +44,20 @@ unifier::unifier()
 QString& unifier::unifyNames(QString& author) const
 {
     // Composite Names temporary unified
-    author.replace(unifier_rx1, "\\1+i+\\2");
-    author.replace(unifier_rx2, "\\1+");
+    c2bUtils::replace(author, unifier_rx1, "\\1+i+\\2");
+    c2bUtils::replace(author, unifier_rx2, "\\1+");
     author.replace("Da+", "Da ", Qt::CaseSensitive);
-    author.replace(unifier_rx3, "\\1+ ");
+    c2bUtils::replace(author, unifier_rx3, "\\1+ ");
     if (author.contains("Jr", Qt::CaseInsensitive))
     {
         // Remove period and first comma if there
-        author.replace(unifier_rx4, "\\1+JR");
-        author.replace(unifier_rx5, "\\1+JR");
+        c2bUtils::replace(author, unifier_rx4, "\\1+JR");
+        c2bUtils::replace(author, unifier_rx5, "\\1+JR");
     }
     if (author.contains('I', Qt::CaseSensitive))
-        author.replace(unifier_rx6, "\\1+\\2");
+        c2bUtils::replace(author, unifier_rx6, "\\1+\\2");
     author.replace('+', '_');
-    author.replace(unifier_rx7, "\\1 "); // Cleaning affiliation 'superscripts'. Avoid cleaning 'M.-m. Lin'
+    c2bUtils::replace(author, unifier_rx7, "\\1 "); // Cleaning affiliation 'superscripts'. Avoid cleaning 'M.-m. Lin'
     return author;
 }
 
@@ -68,14 +68,13 @@ QString& unifier::simplifyString(QString& author, const bool full) const
         author.replace('|', ' ');
         author.replace(':', ' ');
     }
-    author.replace(simplify_string_rx1, "\'"); // Normalize apostrophe
-    author.remove(simplify_string_rx2);        // Remove spurious apostrophes
-    author.replace(simplify_string_rx3, "/");  // Break dates, addresses, etc, but remove from author's foot notes.
-    author.replace(simplify_string_rx4, ",");  // Help no-separator designs, and also break zip codes.
-    author.replace(simplify_string_rx5, " ");
-    author.remove(
-        simplify_string_rx6); // Better remove if no conflict. It will help to not confuse with chemical formula.
-    author.replace(simplify_string_rx7, " ");
+    c2bUtils::replace(author, simplify_string_rx1, "\'"); // Normalize apostrophe
+    c2bUtils::remove(author, simplify_string_rx2);        // Remove spurious apostrophes
+    c2bUtils::replace(author, simplify_string_rx3, "/");  // Break dates, addresses, etc, but remove from author's foot notes.
+    c2bUtils::replace(author, simplify_string_rx4, ",");  // Help no-separator designs, and also break zip codes.
+    c2bUtils::replace(author, simplify_string_rx5, " ");
+    c2bUtils::remove(author, simplify_string_rx6);        // Better remove if no conflict. It will help to not confuse with chemical formula.
+    c2bUtils::replace(author, simplify_string_rx7, " ");
     author = c2bUtils::simplifyString(author);
     return author;
 }
@@ -91,7 +90,7 @@ QString unifier::fromMedline(const QString& author) const
     // AU   -  Steketee GS
 
     QString FullN(author.simplified());
-    FullN.replace(QRegExp("\\b" + prefixes + "\\s", Qt::CaseInsensitive), "\\1+");
+    c2bUtils::replace(FullN, QRegExp("\\b" + prefixes + "\\s", Qt::CaseInsensitive), "\\1+");
     FullN.replace('+', '_');
     QStringList parts;
     QString LastN;
@@ -114,7 +113,7 @@ QString unifier::fromMedline(const QString& author) const
         {
             LastN = LastN.toLower();
             LastN[0] = LastN.at(0).toUpper();
-            int ii(LastN.indexOf(QRegExp("[-']")));
+            int ii(QRegExp("[-']").indexIn(LastN));
             if (ii++ > 0)
                 LastN[ii] = LastN.at(ii).toUpper();
         }
@@ -124,14 +123,14 @@ QString unifier::fromMedline(const QString& author) const
     QString isSuffix;
     if (parts.count() > 0)
         isSuffix = parts.last();
-    if (isSuffix.contains(QRegExp("\\b(?:2nd|3rd|Jr|II|III)\\b")))
+    if (QRegExp("\\b(?:2nd|3rd|Jr|II|III)\\b").indexIn(isSuffix) >= 0)
     {
-        isSuffix.replace(QRegExp("\\b2nd\\b"), "II");
-        isSuffix.replace(QRegExp("\\b3rd\\b"), "III");
+        c2bUtils::replace(isSuffix, QRegExp("\\b2nd\\b"), "II");
+        c2bUtils::replace(isSuffix, QRegExp("\\b3rd\\b"), "III");
         LastN += ' ' + isSuffix;
-        FirstN.remove(QRegExp("\\b(?:2nd|3rd|Jr|II|III)\\b"));
+        c2bUtils::remove(FirstN, QRegExp("\\b(?:2nd|3rd|Jr|II|III)\\b"));
     }
-    LastN.replace(QRegExp(prefixes + '_', Qt::CaseInsensitive), "\\1 ");
+    c2bUtils::replace(LastN, QRegExp(prefixes + '_', Qt::CaseInsensitive), "\\1 ");
     FullN = LastN + ',' + FirstN;
     return FullN;
 }
@@ -383,8 +382,8 @@ QString authorString::toBibTeX(const QString& author, bool full_form)
     const bool has_comma(_author_string.contains(','));
     const bool has_semicolon(_author_string.contains(';'));
     const bool has_ands(_author_string.count(" and ") > 1);
-    const bool is_first_reversed(_author_string.contains(au.reversed_name_rx));
-    const bool is_special_case(_author_string.contains(au.reversed_romance_name_rx));
+    const bool is_first_reversed(au.reversed_name_rx.indexIn(_author_string) >= 0);
+    const bool is_special_case(au.reversed_romance_name_rx.indexIn(_author_string) >= 0);
     bool is_string_reversed((has_comma && has_semicolon) || (has_comma && has_ands) || is_special_case);
 
     QString separator;
@@ -396,17 +395,17 @@ QString authorString::toBibTeX(const QString& author, bool full_form)
     {
         if (is_first_reversed)
         {
-            if (_author_string.contains(QRegExp('^' + au.name + ",(?:\\s*-{0,1}\\b\\w\\b\\.){1,3},\\s*" + au.name)))
+            if (QRegExp('^' + au.name + ",(?:\\s*-{0,1}\\b\\w\\b\\.){1,3},\\s*" + au.name).indexIn(_author_string) >= 0)
             {
-                _author_string.replace(QRegExp("\\bJr.", Qt::CaseSensitive), "Jr");
+                c2bUtils::replace(_author_string, QRegExp("\\bJr.", Qt::CaseSensitive), "Jr");
                 _author_string.replace(".,", ".;");
                 // Reversed, comma separated 'Abrahamsson, A.-L., Springett, J., Karlsson, L., Ottosson, T.'
                 separator = ';';
                 is_string_reversed = true;
             }
-            else if (_author_string.contains(QRegExp('^' + au.name + ',' + au.initials + ',')))
+            else if (QRegExp('^' + au.name + ',' + au.initials + ',').indexIn(_author_string) >= 0)
             {
-                _author_string.replace(QRegExp("^([-'\\w]+),"), "\\1 ");
+                c2bUtils::replace(_author_string, QRegExp("^([-'\\w]+),"), "\\1 ");
                 separator = ','; // Mixed naming 'Smith, J.-L., R. Jones, and K. Gibbons'
             }
             else
@@ -423,15 +422,15 @@ QString authorString::toBibTeX(const QString& author, bool full_form)
         separator = " and ";
     c2bUtils::debug(QObject::tr("Separator: |%1|").arg(separator));
     c2bUtils::debug("1--|" + _author_string + '|');
-    _author_string.replace(QRegExp("\\band\\b", Qt::CaseInsensitive), separator);
-    _author_string.replace(QRegExp("\\s&\\s", Qt::CaseInsensitive), separator);
+    c2bUtils::replace(_author_string, QRegExp("\\band\\b", Qt::CaseInsensitive), separator);
+    c2bUtils::replace(_author_string, QRegExp("\\s&\\s", Qt::CaseInsensitive), separator);
     c2bUtils::debug("2--|" + _author_string + '|');
-    _author_string.remove(QRegExp("[^\\w\\.]+$")); // Removing of duplicate commas and semicolons
-    _author_string.replace(QRegExp(",\\s*"), ",");
+    c2bUtils::remove(_author_string, QRegExp("[^\\w\\.]+$")); // Removing of duplicate commas and semicolons
+    c2bUtils::replace(_author_string, QRegExp(",\\s*"), ",");
     c2bUtils::debug("3--|" + _author_string + '|');
-    _author_string.replace(QRegExp(",+"), ",");
-    _author_string.replace(QRegExp(";\\s*"), ";");
-    _author_string.replace(QRegExp(";+"), ";");
+    c2bUtils::replace(_author_string, QRegExp(",+"), ",");
+    c2bUtils::replace(_author_string, QRegExp(";\\s*"), ";");
+    c2bUtils::replace(_author_string, QRegExp(";+"), ";");
     c2bUtils::debug("4--|" + _author_string + '|');
     const bool are_authors_in_uppercase(containUpperCaseLetter(_author_string) &&
                                         !containLowerCaseLetter(_author_string));
@@ -439,15 +438,15 @@ QString authorString::toBibTeX(const QString& author, bool full_form)
         c2bUtils::debug("Input Authors in Uppercase");
     QStringList authors;
     if (separator == " and ")
-        authors = _author_string.split(QRegExp("\\band\\b"));
+        authors = c2bUtils::split(_author_string, QRegExp("\\band\\b"), _QT_6_KeepEmptyParts);
     else
-        authors = _author_string.split(separator);
+        authors = _author_string.split(separator, _QT_6_KeepEmptyParts);
 
     // Setting author ordering
     const QString first_author(authors.first().trimmed());
     bool is_current_reversed(is_string_reversed || is_first_reversed || isReverseOrder(first_author));
     const QString last_author(authors.last().trimmed());
-    const bool is_last_reversed(is_string_reversed || last_author.contains(au.reversed_name_rx) ||
+    const bool is_last_reversed(is_string_reversed || au.reversed_name_rx.indexIn(last_author) >= 0 ||
                                 isReverseOrder(last_author));
     const bool is_string_mixed(is_current_reversed && !is_last_reversed);
     if (is_string_mixed) // Mixed naming 'Smith, J., R. Jones'
@@ -458,8 +457,8 @@ QString authorString::toBibTeX(const QString& author, bool full_form)
     {
         QString author_i(authors.at(ai));
         c2bUtils::debug(author_i);
-        author_i.replace(QRegExp("\\.{0,1}\\s{0,1}-"), "-"); // Abbreviated cases, eg M.-H. Something
-        author_i.replace(QRegExp("[^-'\\w,]"), " ");         // Only these characters compose a name; keep commas
+        c2bUtils::replace(author_i, QRegExp("\\.{0,1}\\s{0,1}-"), "-"); // Abbreviated cases, eg M.-H. Something
+        c2bUtils::replace(author_i, QRegExp("[^-'\\w,]"), " ");         // Only these characters compose a name; keep commas
         author_i = c2bUtils::simplifyString(author_i);
 
         // Split author name
@@ -482,7 +481,7 @@ QString authorString::toBibTeX(const QString& author, bool full_form)
                 if (p.count() > 0)
                     last_name = p.takeLast();
                 fore_name_parts = parts.at(1).split(' ', _QT_6_SkipEmptyParts) + p;
-                if (parts.last().contains(QRegExp("^(?:Jr|II|III|IV)$"))) // If otherwise, ignore it
+                if (QRegExp("^(?:Jr|II|III|IV)$").indexIn(parts.last()) >= 0) // If otherwise, ignore it
                     last_name += '_' + parts.last();
             }
             else
@@ -521,26 +520,26 @@ QString authorString::toBibTeX(const QString& author, bool full_form)
                 const int fore_length(fore_name.length());
                 const bool is_uppercase(!containLowerCaseLetter(fore_name));
                 if (fore_name_parts.count() == 1 && fore_length > 1 &&
-                    !fore_name.contains(QRegExp("\\b" + au.double_initials + '_', Qt::CaseInsensitive)) &&
+                    QRegExp("\\b" + au.double_initials + '_', Qt::CaseInsensitive).indexIn(fore_name) == -1 &&
                     !are_authors_in_uppercase && is_uppercase)
                 {
                     // Cases 'Last, FST': Always abbreviated, no call to processFirstMiddle
                     for (int l = 0; l < fore_length; ++l)
-                        author_name += fore_name[l] + ". ";
+                        author_name += fore_name.at(l) + QLatin1String(". ");
                 }
                 else if (fore_name_parts.count() == 2 && fore_length > 1 && fore_length < 3 && is_current_reversed &&
                          !are_authors_in_uppercase && is_uppercase)
                 {
                     // Cases 'Last1 Last2, FST': Always abbreviated, no call to processFirstMiddle
                     for (int l = 0; l < fore_length; ++l)
-                        author_name += fore_name[l] + ". ";
+                        author_name += fore_name.at(l) + QLatin1String(". ");
                 }
                 else if (i == 1 && fore_name_parts.count() == 2 && fore_length > 1 && fore_length < 3 &&
                          !is_current_reversed && !are_authors_in_uppercase && is_uppercase)
                 {
                     // Cases 'Fore IJ Last': Process initials
                     for (int l = 0; l < fore_length; ++l)
-                        author_name += fore_name[l] + ". ";
+                        author_name += fore_name.at(l) + QLatin1String(". ");
                 }
                 else
                     author_name += processFirstMiddle(fore_name) + ' ';
@@ -558,12 +557,12 @@ QString authorString::toBibTeX(const QString& author, bool full_form)
     _author_string = authors.join(" and ");
     // Restore Composite Names white spaces
     _author_string.replace("_i_", " i ");
-    _author_string.replace(QRegExp("_II\\b", Qt::CaseInsensitive), " II"); // Suffix can be lower case here
-    _author_string.replace(QRegExp("_III\\b", Qt::CaseInsensitive), " III");
-    _author_string.replace(QRegExp("_IV\\b", Qt::CaseInsensitive), " IV");
-    _author_string.replace(QRegExp("_JR\\b", Qt::CaseInsensitive), " Jr");
-    _author_string.replace(QRegExp(au.prefixes + '_', Qt::CaseInsensitive), "\\1 ");
-    _author_string.replace(QRegExp("\\b" + au.double_initials + '_', Qt::CaseInsensitive), "\\1.");
+    c2bUtils::replace(_author_string, QRegExp("_II\\b", Qt::CaseInsensitive), " II"); // Suffix can be lower case here
+    c2bUtils::replace(_author_string, QRegExp("_III\\b", Qt::CaseInsensitive), " III");
+    c2bUtils::replace(_author_string, QRegExp("_IV\\b", Qt::CaseInsensitive), " IV");
+    c2bUtils::replace(_author_string, QRegExp("_JR\\b", Qt::CaseInsensitive), " Jr");
+    c2bUtils::replace(_author_string, QRegExp(au.prefixes + '_', Qt::CaseInsensitive), "\\1 ");
+    c2bUtils::replace(_author_string, QRegExp("\\b" + au.double_initials + '_', Qt::CaseInsensitive), "\\1.");
     _author_string = c2bUtils::simplifyString(_author_string);
 
     return _author_string;
@@ -603,21 +602,21 @@ QString authorString::capitalize(const QString& name) const
         return QString();
     QString proc_name(name);
     int ii(0);
-    const int prefixes(proc_name.count(QRegExp(au.prefixes + "_(?!(?:Jr|II|III|IV)\\b)", Qt::CaseInsensitive)));
+    const int prefixes(c2bUtils::count(proc_name, QRegExp(au.prefixes + "_(?!(?:Jr|II|III|IV)\\b)", Qt::CaseInsensitive)));
     for (int p = 0; p < prefixes; ++p)
     {
         const int iin(proc_name.indexOf('_', ii));
         if (c2bUtils::isUpperCaseString(proc_name, ii, iin))
             for (int i = 0; i < iin; ++i)
                 proc_name[i] = proc_name.at(i).toLower();
-        ii = std::min(iin + 1, proc_name.length() - 1);
+        ii = std::min(iin + 1, int(proc_name.length()) - 1);
     }
     if (c2bUtils::isUpperCaseString(proc_name, ii))
     {
         proc_name[ii] = proc_name.at(ii).toUpper();
         for (int i = ++ii; i < proc_name.length(); ++i)
             proc_name[i] = proc_name.at(i).toLower();
-        ii = proc_name.indexOf(QRegExp("[\\s-']")); // As before, assume just one part
+        ii = QRegExp("[\\s-']").indexIn(proc_name); // As before, assume just one part
         if (ii++ > 0)
             if (ii < proc_name.length())
                 proc_name[ii] = proc_name.at(ii).toUpper();
@@ -682,9 +681,9 @@ bool authorString::isReverseOrder(const QString& author) const
 bool authorString::containLowerCaseLetter(const QString& author) const
 {
     QString author_line(author);
-    author_line.remove(QRegExp("\\band\\b"));                                 // Remove possible 'and' separator
-    author_line.remove(QRegExp(au.prefixes + '_', Qt::CaseInsensitive));      // Remove possible prefixes
-    author_line.remove(QRegExp(au.double_initials + '_', Qt::CaseSensitive)); // Remove possible two-letter initials
+    c2bUtils::remove(author_line, QRegExp("\\band\\b"));                                 // Remove possible 'and' separator
+    c2bUtils::remove(author_line, QRegExp(au.prefixes + '_', Qt::CaseInsensitive));      // Remove possible prefixes
+    c2bUtils::remove(author_line, QRegExp(au.double_initials + '_', Qt::CaseSensitive)); // Remove possible two-letter initials
     for (int i = 0; i < author_line.length(); i++)
     {
         if (author_line.at(i).isLetter())
