@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef AUTHORSTRING_H
@@ -79,7 +79,7 @@ struct encoder
     void scape(const int pos, const int length, const QChar c = QChar(' '))
     {
         const int pos0(std::max(pos, 0));
-        const int posn(std::min(pos0 + length, code.length()));
+        const int posn(std::min(pos0 + length, int(code.length())));
         for (int i = pos0; i < posn; ++i)
             if (code.at(i) != 'L')
                 code[i] = c;
@@ -112,7 +112,7 @@ struct encoder
     }
     static inline bool isCapitalName(const QString& w)
     {
-        return c2bUtils::isUpperCaseString(w, std::max(0, w.lastIndexOf('_', -5))); // Skip prefixes and suffixes
+        return c2bUtils::isUpperCaseString(w, std::max(0, int(w.lastIndexOf('_', -5)))); // Skip prefixes and suffixes
     }
     static inline bool isSeparator(const QString& w)
     {
