@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "bibParser.h"
@@ -80,13 +80,13 @@ QString bibParser::parse(const QString& field, const QString& value, const QStri
     else if (field == QLatin1String("editor"))
     {
         c2bUtils::debug(v);
-        v.remove(QRegExp("\\((Editor|Editors|Ed|Eds)\\.{0,1}\\)", Qt::CaseInsensitive));
+        c2bUtils::remove(v, QRegExp("\\((Editor|Editors|Ed|Eds)\\.{0,1}\\)", Qt::CaseInsensitive));
         v = _authorString.toBibTeX(v, _settingsP->value("cb2Bib/UseFullNames").toBool());
     }
     else if (field == QLatin1String("addeditors"))
     {
         c2bUtils::debug(v);
-        v.remove(QRegExp("\\((Editor|Editors|Ed|Eds)\\.{0,1}\\)", Qt::CaseInsensitive));
+        c2bUtils::remove(v, QRegExp("\\((Editor|Editors|Ed|Eds)\\.{0,1}\\)", Qt::CaseInsensitive));
         if (init_value.isEmpty())
             v = _authorString.toBibTeX(v, _settingsP->value("cb2Bib/UseFullNames").toBool());
         else
@@ -94,7 +94,7 @@ QString bibParser::parse(const QString& field, const QString& value, const QStri
     }
     else if (field == QLatin1String("doi"))
     {
-        v.remove(QRegExp("^.+(?=10\\.[\\d\\.]+/\\S+)"));
+        c2bUtils::remove(v, QRegExp("^.+(?=10\\.[\\d\\.]+/\\S+)"));
         if (v.endsWith(QLatin1Char('.')) || v.endsWith(QLatin1Char(',')) || v.endsWith(QLatin1Char(';')))
             v.chop(1);
     }
@@ -116,11 +116,11 @@ QString bibParser::parse(const QString& field, const QString& value, const QStri
     else if (field == QLatin1String("keywords"))
     {
         v.replace(" - ", ",");
-        QStringList kl(v.split(QRegExp("[^\\w\\s-']"), _QT_6_SkipEmptyParts));
+        QStringList kl(c2bUtils::split(v, QRegExp("[^\\w\\s-']"), _QT_6_SkipEmptyParts));
         kl.removeAll(" ");
         kl.removeDuplicates();
         v = kl.join(", ");
-        v.replace(QRegExp("\\s+,"), ",");
+        c2bUtils::replace(v, QRegExp("\\s+,"), ",");
         v = v.toLower();
     }
     else if (field == QLatin1String("month"))
@@ -226,23 +226,19 @@ QString bibParser::setJournalsToAbbreviated(const QString& text, const bool alte
 QString bibParser::excerpt(const QString& text, const QStringList& hints) const
 {
     QString txt(removeTags(text));
-    txt.replace(QRegExp("\\[Bibliographic Metadata.+/Bibliographic Metadata\\]"), " ");
-    txt.replace(QRegExp("(http://|https://|ftp://|www\\.|ftp\\.)(www\\.|ftp\\.){0,1}\\S+"), " ");
-    txt.replace(QRegExp("\\b[A-Z]+\\b"), " ");
-    txt.replace(QRegExp("\\d"), " ");
-    txt.replace(c2bUtils::nonLetter, " ");
-    txt.replace(QRegExp("\\b\\w{1,2}\\b"), " ");
-    txt.replace(
-        QRegExp("\\b(about|and|are|com|for|from|how|into|that|the|their|this|where|with|www)\\b", Qt::CaseInsensitive),
-        " ");
-    txt.replace(QRegExp("\\b(january|february|march|april|may|june|july|august|september|october|november|december)\\b",
-                        Qt::CaseInsensitive),
-                " ");
+    c2bUtils::replace(txt, QRegExp("\\[Bibliographic Metadata.+/Bibliographic Metadata\\]"), " ");
+    c2bUtils::replace(txt, QRegExp("(http://|https://|ftp://|www\\.|ftp\\.)(www\\.|ftp\\.){0,1}\\S+"), " ");
+    c2bUtils::replace(txt, QRegExp("\\b[A-Z]+\\b"), " ");
+    c2bUtils::replace(txt, QRegExp("\\d"), " ");
+    c2bUtils::replace(txt, c2bUtils::nonLetter, " ");
+    c2bUtils::replace(txt, QRegExp("\\b\\w{1,2}\\b"), " ");
+    c2bUtils::replace(txt, QRegExp("\\b(about|and|are|com|for|from|how|into|that|the|their|this|where|with|www)\\b", Qt::CaseInsensitive), " ");
+    c2bUtils::replace(txt, QRegExp("\\b(january|february|march|april|may|june|july|august|september|october|november|december)\\b", Qt::CaseInsensitive), " ");
     txt = hints.join(" ") + ' ' + txt;
     txt = c2bUtils::simplifyString(txt);
     const QStringList txtlist(txt.split(' ', _QT_6_SkipEmptyParts));
     QStringList txtlistSimp;
-    for (int i = 0; i < std::min(15, txtlist.count()); ++i)
+    for (int i = 0; i < std::min(15, int(txtlist.count())); ++i)
         txtlistSimp.append(txtlist.at(i));
     return txtlistSimp.join(" ");
 }
@@ -281,7 +277,7 @@ QString bibParser::documentFilename(const QString& base_fn, const QString& bibte
     QFileInfo fi(base_fn);
     QString docExtension('.' + fi.suffix().toLower());
     // Possible document extensions
-    if (!docExtension.contains(QRegExp("^\\.\\w{2,4}$")))
+    if (QRegExp("^\\.\\w{2,4}$").indexIn(docExtension) == -1)
         docExtension = ".pdf"; // Default
     if (docExtension == ".gz")
         if (fi.completeSuffix().toLower() == ".ps.gz")
@@ -447,16 +443,15 @@ void bibParser::parse(const QString& text, QString* out_text, QString* out_tagte
         return;
     }
 
-    if (otext.contains(QRegExp("^\\s*PMID\\s*-")))
+    if (QRegExp("^\\s*PMID\\s*-").indexIn(otext) >= 0)
     {
         _current_reference.typeName = "article";
         otext = ' ' + otext;
-        ottext = otext;
         // http://www.nlm.nih.gov/bsd/mms/medlineelements.html
-        ottext.replace(QRegExp("[\\n\\r]\\s*([A-Z]{2,4}\\s*-)"), "][\\1"); // Two to four capital letter in field tags
+        ottext = c2bUtils::replaced(otext, QRegExp("[\\n\\r]\\s*([A-Z]{2,4}\\s*-)"), "][\\1"); // Two to four capital letter in field tags
         ottext = c2bUtils::simplifyString(ottext);
-        if (!ottext.contains(QRegExp("\\[FAU\\s+-")))
-            ottext.replace(QRegExp("\\[(AU\\s*-\\s*[-'\\w]+)"), "[F\\1 ");
+        if (QRegExp("\\[FAU\\s+-").indexIn(ottext) == -1)
+            c2bUtils::replace(ottext, QRegExp("\\[(AU\\s*-\\s*[-'\\w]+)"), "[F\\1 ");
         QStringList fList(ottext.split("]["));
         QString kw;
         QRegExp fld("^([A-Z]{2,4})\\s{0,1}-\\s*(.+)$");
@@ -470,8 +465,7 @@ void bibParser::parse(const QString& text, QString* out_text, QString* out_tagte
             if (tag == "AB")
                 _current_reference["abstract"] = parse("abstract", value);
             else if (tag == "FAU")
-                _current_reference["author"] =
-                    parse("addauthors", authorFromMedline(value), _current_reference.value("author"));
+                _current_reference["author"] = parse("addauthors", authorFromMedline(value), _current_reference.value("author"));
             else if (tag == "TA")
                 _current_reference["journal"] = parse("journal", value);
             else if (tag == "IP")
@@ -490,7 +484,7 @@ void bibParser::parse(const QString& text, QString* out_text, QString* out_tagte
                     _current_reference["doi"] = parse("doi", value.remove("[doi]"));
             }
             else if (tag == "DP")
-                _current_reference["year"] = parse("year", value.replace(QRegExp("^([\\d\\s]+).*$"), "\\1"));
+                _current_reference["year"] = parse("year", c2bUtils::replaced(value, QRegExp("^([\\d\\s]+).*$"), "\\1"));
             else if (tag == "MH")
                 kw += "; " + value.trimmed();
         }
@@ -507,23 +501,32 @@ void bibParser::parse(const QString& text, QString* out_text, QString* out_tagte
 
     // Set tags and start regular expression extraction
     ottext = setTags(otext);
-    QString regular_expression_f(_settingsP->fileName("cb2Bib/RegularExpressionFile"));
+    const QString regular_expression_f(_settingsP->fileName("cb2Bib/RegularExpressionFile"));
     checkRegExpFile(regular_expression_f);
     QFile file(regular_expression_f);
-    file.open(QIODevice::ReadOnly | QIODevice::Text);
+    if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
+    {
+        _auto_recognized_string = tr("Failed to open '%1' file.").arg(regular_expression_f);
+        emit statusMessage(_auto_recognized_string);
+        return;
+    }
     QString ItemX;
     QString line;
     QString reftype;
     QString fieldset;
     QTextStream stream(&file);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    stream.setEncoding(QStringConverter::Utf8);
+#else
     stream.setCodec("UTF-8");
+#endif
     stream.setAutoDetectUnicode(true);
     int nfilters(0);
 
     while (!stream.atEnd())
     {
         line = stream.readLine();
-        if (!(line.isEmpty() || line.contains(QRegExp("^#"))))
+        if (!(line.isEmpty() || QRegExp("^#").indexIn(line) >= 0))
         {
             reftype = stream.readLine();
             fieldset = stream.readLine();
@@ -634,16 +637,16 @@ void bibParser::guessFields(const QString& text)
 QString bibParser::setTags(const QString& text) const
 {
     QString tagged_text(text.trimmed());
-    tagged_text.replace(QRegExp("\\r\\n"), "<found_new_line>"); // Windows new line
-    tagged_text.replace(QRegExp("\\n"), "<found_new_line>");    // Linux new line, LF
-    tagged_text.replace(QRegExp("\\r"), "<found_new_line>");    // OSX new line, CR
+    c2bUtils::replace(tagged_text, QRegExp("\\r\\n"), "<found_new_line>"); // Windows new line
+    c2bUtils::replace(tagged_text, QRegExp("\\n"), "<found_new_line>");    // Linux new line, LF
+    c2bUtils::replace(tagged_text, QRegExp("\\r"), "<found_new_line>");    // OSX new line, CR
     QStringList spText(tagged_text.split("<found_new_line>"));
     int n(spText.count());
     tagged_text.clear();
     for (int i = 0; i < n - 1; i++)
         tagged_text += spText.at(i) + QString("<NewLine%1>").arg(i + 1);
     tagged_text += spText[n - 1];
-    spText = tagged_text.split(QRegExp("(\\s{10,}|\\t)"));
+    spText = c2bUtils::split(tagged_text, QRegExp("(\\s{10,}|\\t)"), _QT_6_KeepEmptyParts);
     n = spText.count();
     tagged_text.clear();
     for (int i = 0; i < n - 1; i++)
@@ -658,15 +661,15 @@ QString bibParser::removeTags(const QString& text) const
     QString clean(text);
     clean.remove("[[");
     clean.remove("]]");
-    clean.replace(QRegExp("<NewLine\\d+>"), " ");
-    clean.replace(QRegExp("<Tab\\d+>"), " ");
+    c2bUtils::replace(clean, QRegExp("<NewLine\\d+>"), " ");
+    c2bUtils::replace(clean, QRegExp("<Tab\\d+>"), " ");
     clean = c2bUtils::simplifyString(clean);
     return clean;
 }
 
 QString bibParser::metadataSection(const QString& text, const QString& identifier) const
 {
-    const QStringList lines(text.split(QRegExp("[\\r\\n]"), _QT_6_KeepEmptyParts));
+    const QStringList lines(c2bUtils::split(text, QRegExp("[\\r\\n]"), _QT_6_KeepEmptyParts));
     const int nl(lines.count());
     int il(-1);
     int sl(0);
