@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "bibSearcher.h"
@@ -14,7 +14,7 @@
 
 /** \page bibsearch Search BibTeX and PDF Document Files
 
-\section descrip Description
+\section searchfunct Search Functionality
 
   - <b>Search pattern</b> \n Patterns and composite patterns can be either
   \htmlonly
@@ -248,7 +248,7 @@ QString bibSearcher::searchDocumentKeyword(const QString& bibtexfn, const QStrin
     if (bs._documents.setCurrent(documentfn))
     {
         QString p(keyword);
-        p.replace(QRegExp("\\W"), ".{0,5}");
+        c2bUtils::replace(p, QRegExp("\\W"), ".{0,5}");
         p.replace("s", ".?");
         p = "\\b" + p + "\\w*\\b";
         bs.addPattern(false, false, searchPattern::type(searchPattern::RegularExpression), QLatin1String("all"),
@@ -310,7 +310,11 @@ void bibSearcher::search(const QString& bib_file)
         return;
     }
     QTextStream stream(&file);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    stream.setEncoding(QStringConverter::Utf8);
+#else
     stream.setCodec("UTF-8");
+#endif
     stream.setAutoDetectUnicode(true);
     bib_file_contents = stream.readAll();
     _log_string += tr("% Scanning file %1\n").arg(bib_file.trimmed());
@@ -555,7 +559,7 @@ QString bibSearcher::excerpts(const QString& contents)
 
     bool item_begins(true);
     bool item_complete;
-    const int items(std::min(i_pos.count(), max_excerpts));
+    const int items(std::min(int(i_pos.count()), max_excerpts));
 
     for (int i = 0; i < items; ++i)
     {
@@ -567,7 +571,7 @@ QString bibSearcher::excerpts(const QString& contents)
         if (item_begins)
         {
             QString pre_match(contents.mid(pos - context_length, context_length));
-            pre_match.remove(lead_truncated_words);
+            c2bUtils::remove(pre_match, lead_truncated_words);
             pre_match = c2bUtils::toHtmlString(pre_match);
             exc += QLatin1String("&#8226; ...") + pre_match + match;
         }
@@ -581,14 +585,14 @@ QString bibSearcher::excerpts(const QString& contents)
         if (item_complete)
         {
             QString post_match(contents.mid(pos + length, context_length));
-            post_match.remove(tail_truncated_words);
+            c2bUtils::remove(post_match, tail_truncated_words);
             post_match = c2bUtils::toHtmlString(post_match);
             exc += post_match + "... ";
             item_begins = true;
         }
         else
         {
-            exc += contents.midRef(pos + length, i_pos.at(i + 1) - pos - length);
+            exc += contents.mid(pos + length, i_pos.at(i + 1) - pos - length);
             item_begins = false;
         }
     }
