@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "cb2bib_utilities.h"
@@ -355,7 +355,7 @@ QString toAscii(const QString& str, const AsciiConversion type)
     if (type == KeepWords || type == FromBibTeX)
         _to_ascii_keep_words(ascii);
     else if (type == Cleanup)
-        ascii.remove(nonAsciiLetter);
+        remove(ascii, nonAsciiLetter);
     return ascii;
 }
 
@@ -934,25 +934,25 @@ const QRegExp pnasGreekLetters("[\\{\\[\\(](alpha|beta|gamma|delta|varepsilon|"
 QString& fullBibToC2b(QString& str)
 {
     // Escape TeX and other special characters to Unicode
-    if (!str.contains(isBibToC2b))
+    if (isBibToC2b.indexIn(str) == -1)
         return str;
     // PNAS Style
-    str.replace(pnasGreekLetters, "$\\\\1$");
+    replace(str, pnasGreekLetters, "$\\\\1$");
     str.replace(QLatin1String("{micro}"), QLatin1String("$\\mu$"));
     str.replace(QLatin1String("{middle dot}"), QLatin1String("$\\cdot$"));
     // Sub and superscripts
-    str.replace(QRegExp("<sub>([^<]*)</sub>"), "$_{\\1}$");
-    str.replace(QRegExp("<sup>([^<]*)</sup>"), "$^{\\1}$");
-    str.replace(QRegExp("\\[sub ([^\\]]*)\\]"), "$_{\\1}$");
-    str.replace(QRegExp("\\[sup ([^\\]]*)\\]"), "$^{\\1}$");
-    str.replace(QRegExp("\\}\\$\\$([_\\^])\\{"), "}\\1{"); // merge if both
+    replace(str, QRegExp("<sub>([^<]*)</sub>"), "$_{\\1}$");
+    replace(str, QRegExp("<sup>([^<]*)</sup>"), "$^{\\1}$");
+    replace(str, QRegExp("\\[sub ([^\\]]*)\\]"), "$_{\\1}$");
+    replace(str, QRegExp("\\[sup ([^\\]]*)\\]"), "$^{\\1}$");
+    replace(str, QRegExp("\\}\\$\\$([_\\^])\\{"), "}\\1{"); // merge if both
     // Normalize TeX
-    str.replace(QRegExp("\\{\\\\(\\W)\\{([\\\\]{0,1}\\w)\\}\\}"), "{\\\\1\\2}");  // {\'{A}} to {\'A}
-    str.replace(QRegExp("\\{\\\\(\\w)\\{([\\\\]{0,1}\\w)\\}\\}"), "{\\\\1 \\2}"); // {\c{C}} to {\c C}
-    str.replace(QRegExp("\\\\(\\W)\\{([\\\\]{0,1}\\w)\\}"), "{\\\\1\\2}");        // \'{A} to {\'A}
-    str.replace(QRegExp("\\\\(\\w)\\{([\\\\]{0,1}\\w)\\}"), "{\\\\1 \\2}");       // \c{C} to {\c C}
-    str.replace(QRegExp("\\{\\\\(.{1,2})\\{(\\w{0,2})\\}\\}"), "{\\\\1\\2}");     // {\\AA{}} to {\\AA}
-    str.replace(QRegExp("\\\\\\{([A-Z]\\w{1,7})\\\\\\}"), "\\1");                 // \{NaCl\} to NaCl
+    replace(str, QRegExp("\\{\\\\(\\W)\\{([\\\\]{0,1}\\w)\\}\\}"), "{\\\\1\\2}");  // {\'{A}} to {\'A}
+    replace(str, QRegExp("\\{\\\\(\\w)\\{([\\\\]{0,1}\\w)\\}\\}"), "{\\\\1 \\2}"); // {\c{C}} to {\c C}
+    replace(str, QRegExp("\\\\(\\W)\\{([\\\\]{0,1}\\w)\\}"), "{\\\\1\\2}");        // \'{A} to {\'A}
+    replace(str, QRegExp("\\\\(\\w)\\{([\\\\]{0,1}\\w)\\}"), "{\\\\1 \\2}");       // \c{C} to {\c C}
+    replace(str, QRegExp("\\{\\\\(.{1,2})\\{(\\w{0,2})\\}\\}"), "{\\\\1\\2}");     // {\\AA{}} to {\\AA}
+    replace(str, QRegExp("\\\\\\{([A-Z]\\w{1,7})\\\\\\}"), "\\1");                 // \{NaCl\} to NaCl
     // TeX to Unicode
     bibToC2b(str);
     return str;
@@ -1042,9 +1042,9 @@ QByteArray compress(const QByteArray& decompressed)
     compressed.resize(sactual + HEADER_LENGTH);
 
     QByteArray header(QByteArray::number(qulonglong(sdecompressed)));
-    for (int i = 0; i < std::min(header.length(), HEADER_LENGTH); ++i)
+    for (int i = 0; i < std::min(int(header.length()), HEADER_LENGTH); ++i)
         compressed[i] = header[i];
-    for (int i = std::min(header.length(), HEADER_LENGTH); i < HEADER_LENGTH; ++i)
+    for (int i = std::min(int(header.length()), HEADER_LENGTH); i < HEADER_LENGTH; ++i)
         compressed[i] = ' ';
     return compressed;
 }
@@ -1125,9 +1125,9 @@ QByteArray compress(const QByteArray& decompressed)
     compressed.resize(sactual + HEADER_LENGTH);
 
     QByteArray header(QByteArray::number(qulonglong(sdecompressed)));
-    for (int i = 0; i < std::min(header.length(), HEADER_LENGTH); ++i)
+    for (int i = 0; i < std::min(int(header.length()), HEADER_LENGTH); ++i)
         compressed[i] = header[i];
-    for (int i = std::min(header.length(), HEADER_LENGTH); i < HEADER_LENGTH; ++i)
+    for (int i = std::min(int(header.length()), HEADER_LENGTH); i < HEADER_LENGTH; ++i)
         compressed[i] = ' ';
     return compressed;
 }
@@ -1214,9 +1214,9 @@ QByteArray compress(const QByteArray& data)
     {
         compressed.resize((int)enc_dest_s + HEADER_LENGTH);
         QByteArray header(QByteArray::number((qulonglong)src_s));
-        for (int i = 0; i < std::min(header.length(), HEADER_LENGTH); ++i)
+        for (int i = 0; i < std::min(int(header.length()), HEADER_LENGTH); ++i)
             compressed[i] = header[i];
-        for (int i = std::min(header.length(), HEADER_LENGTH); i < HEADER_LENGTH; ++i)
+        for (int i = std::min(int(header.length()), HEADER_LENGTH); i < HEADER_LENGTH; ++i)
             compressed[i] = ' ';
         return compressed;
     }
@@ -1243,7 +1243,7 @@ QByteArray decompress(const QByteArray& data)
 
     QByteArray decompressed;
     const ulong expected_dest_s = data.left(HEADER_LENGTH).trimmed().toULong();
-    lzo_uint dest_s = std::max(expected_dest_s, lzo_uint(1));
+    lzo_uint dest_s = std::max(lzo_uint(expected_dest_s), lzo_uint(1));
     decompressed.resize((int)dest_s);
     lzo_bytep dest_p = reinterpret_cast<lzo_bytep>(decompressed.data());
 
