@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "collectionIndex.h"
@@ -27,10 +27,8 @@ static const int _document_length_threshold(100000);
 static const int _in_long_document_sentence_repetition(3);
 static const int _in_short_document_sentence_repetition(2);
 static const int _inter_document_sentence_repetition(3);
-
-#if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)
-static const QRegularExpression::PatternOptions _qre_pattern_options(QRegularExpression::UseUnicodePropertiesOption |
-        QRegularExpression::OptimizeOnFirstUsageOption);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0) & QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+static const QRegularExpression::PatternOptions _qre_pattern_options(QRegularExpression::UseUnicodePropertiesOption | QRegularExpression::OptimizeOnFirstUsageOption);
 #else
 static const QRegularExpression::PatternOptions _qre_pattern_options(QRegularExpression::UseUnicodePropertiesOption);
 #endif
