@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "coreBibParser.h"
@@ -80,7 +80,7 @@ QString coreBibParser::referenceToFomattedBibTeX(const bibReference& ref) const
             if (fd == QLatin1String("title") || fd == QLatin1String("booktitle"))
             {
                 if (UseDoubleBraces)
-                    if (!fvalue.contains(QRegExp("^\\{.+\\}$")))
+                    if (QRegExp("^\\{.+\\}$").indexIn(fvalue) == -1)
                         fvalue = '{' + fvalue + '}';
                 fvalue = QLatin1Char('{') + fvalue + QLatin1Char('}');
             }
@@ -124,7 +124,7 @@ QString coreBibParser::adjacentNumbers(const QString& numbers) const
 {
     // Originally for pages, used also for multiple volume, number and year
     QString anums(numbers);
-    anums.replace(c2bUtils::nonLetter, QLatin1String(" "));
+    c2bUtils::replace(anums, c2bUtils::nonLetter, QLatin1String(" "));
     anums = c2bUtils::simplifyString(anums);
     if (anums.isEmpty() || anums == QLatin1String("0"))
         return QString();
@@ -259,7 +259,7 @@ QString coreBibParser::singleReferenceField(const QString& field, const bibRefer
                 continue;
             else
                 break;
-        if (field.compare(ref.unicodeReference.midRef(cursor + 1, fends - cursor), Qt::CaseInsensitive) != 0)
+        if (field.compare(ref.unicodeReference.mid(cursor + 1, fends - cursor), Qt::CaseInsensitive) != 0)
         {
             cursor = cd + 2;
             continue;
