@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "crJson.h"
@@ -203,8 +203,8 @@ QString crJson::_normalize_jabstract(const QString& abstract)
     QString na(abstract);
     na.replace("&lt;", "<");
     na.replace("&gt;", ">");
-    na.replace(QRegExp("<[^>]+>"), " ");
-    na.remove(QRegExp("^\\W*(abstract|synopsis|summary)\\.*", Qt::CaseInsensitive));
+    c2bUtils::replace(na, QRegExp("<[^>]+>"), " ");
+    c2bUtils::remove(na, QRegExp("^\\W*(abstract|synopsis|summary)\\.*", Qt::CaseInsensitive));
     return na.simplified();
 }
 
@@ -227,8 +227,8 @@ QString crJson::_bibtex_booktitle(const QStringList& titles)
     if (titles.count() == 0)
         return QString();
     if (titles.count() == 2)
-        return (!titles.at(1).contains(
-                    QRegExp("(advances|series|lecture notes|studies in|topics in)", Qt::CaseInsensitive)))
+        return (QRegExp("(advances|series|lecture notes|studies in|topics in)",
+                        Qt::CaseInsensitive).indexIn(titles.at(1)) == -1)
                ? titles.at(1)
                : titles.at(0);
     return titles.first();
@@ -237,8 +237,8 @@ QString crJson::_bibtex_booktitle(const QStringList& titles)
 QString crJson::_bibtex_series(const QStringList& titles)
 {
     if (titles.count() == 2)
-        return (titles.at(1).contains(
-                    QRegExp("(advances|series|lecture notes|studies in|topics in)", Qt::CaseInsensitive)))
+        return (QRegExp("(advances|series|lecture notes|studies in|topics in)",
+                        Qt::CaseInsensitive).indexIn(titles.at(1)) >= 0)
                ? titles.at(1)
                : titles.at(0);
     return QString();
@@ -246,7 +246,7 @@ QString crJson::_bibtex_series(const QStringList& titles)
 
 int crJson::_words(const QString& s)
 {
-    QStringList wl(s.split(QRegExp("\\W"), _QT_6_SkipEmptyParts));
+    QStringList wl(c2bUtils::split(s, QRegExp("\\W"), _QT_6_SkipEmptyParts));
     wl.removeDuplicates();
     return wl.count();
 }
