@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "document.h"
@@ -320,7 +320,7 @@ QString& document::normalize(QString& doc, const Conversion mode)
     if (hreg)
     {
         // Correct frequent misencoding of "fi" as circle R in PDFs (Adobe Standard Encoding)
-        doc.replace(QRegExp(QString("%1([a-z])").arg(QChar(174))), "fi\\1");
+        c2bUtils::replace(doc, QRegExp(QString("%1([a-z])").arg(QChar(174))), "fi\\1");
     }
     if (hligatures)
     {
@@ -353,7 +353,7 @@ QString& document::normalize(QString& doc, const Conversion mode)
     if (hdieresis)
     {
         const QChar dieresis(168);
-        doc.replace(QRegExp(dieresis + ' ' + '+'), dieresis);
+        c2bUtils::replace(doc, QRegExp(dieresis + ' ' + '+'), dieresis);
         doc.replace(dieresis + ' ', dieresis);
         doc.replace('a' + dieresis, QChar(228));
         doc.replace('e' + dieresis, QChar(235));
