@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "heuristicBibParser.h"
@@ -45,7 +45,7 @@ heuristicBibParser::heuristicBibParser(bibParser* bp)
     // P. Constans. A Simple Extraction Procedure for Bibliographical Author Field.
     // arXiv:0902.0755, 2009.
     _word_prefix_lexicon =
-        c2bUtils::fileToString(":/txt/txt/word_prefix_lexicon.txt").split(c2bUtils::nonLetter, _QT_6_SkipEmptyParts);
+        c2bUtils::split(c2bUtils::fileToString(":/txt/txt/word_prefix_lexicon.txt"), c2bUtils::nonLetter, _QT_6_SkipEmptyParts);
     for (int i = 0; i < _word_prefix_lexicon.count(); ++i)
     {
         _word_prefix_lexicon[i].replace('_', ' ');
@@ -117,7 +117,7 @@ heuristicBibParser::~heuristicBibParser()
 void heuristicBibParser::guessFields(const QString& clean_text, const QString& tagged_text)
 {
     QString clean_num(clean_text);
-    clean_num.replace(_hyphens, "-");
+    c2bUtils::replace(clean_num, _hyphens, "-");
     // Order is important to increase the chances of a proper recognition
     guessJournal(clean_text);
     guessAbstract(tagged_text);
@@ -152,7 +152,7 @@ void heuristicBibParser::heuristicFields(const QString& text)
         // This happens when publishers set doi to title in metadata: <title>doi:10. ... </title>
         if (cdoi.endsWith("</title>"))
             cdoi.chop(8);
-        cdoi.remove(QRegExp("[\\,\"\\}\\)]+$"));
+        c2bUtils::remove(cdoi, QRegExp("[\\,\"\\}\\)]+$"));
         _current_reference["doi"] = _bpP->parse("doi", cdoi);
     }
 
@@ -161,7 +161,7 @@ void heuristicBibParser::heuristicFields(const QString& text)
     {
         // https://arxiv.org/hypertex/bibstyles/
         QString aid(rxarxiv.cap(1));
-        aid.remove(QRegExp("v\\d{1,2}$"));
+        c2bUtils::remove(aid, QRegExp("v\\d{1,2}$"));
         _current_reference["eprint"] = _bpP->parse("eprint", aid);
         _current_reference["journal"] = _bpP->parse("journal", "arXiv:" + aid);
         _current_reference["url"] = _bpP->parse("url", c2bUtils::arxivUrl.arg(aid));
@@ -194,7 +194,7 @@ void heuristicBibParser::guessAbstract(const QString& text)
         if (nH > -1)
             if (rxH.cap(1).length() > 93)
             {
-                const QString val(rxH.cap(1).remove(_leading_non_letters));
+                const QString val(c2bUtils::removed(rxH.cap(1), _leading_non_letters));
                 _current_reference[_abstract] = _bpP->parse(_abstract, val);
                 return;
             }
@@ -205,7 +205,7 @@ void heuristicBibParser::guessAbstract(const QString& text)
         nH = rxH.indexIn(text);
         if (nH > -1)
         {
-            const QString val(rxH.cap(1).remove(_leading_non_letters));
+            const QString val(c2bUtils::removed(rxH.cap(1), _leading_non_letters));
             _current_reference[_abstract] = _bpP->parse(_abstract, val);
             return;
         }
@@ -215,7 +215,7 @@ void heuristicBibParser::guessAbstract(const QString& text)
         if (nH > -1)
             if (rxH.cap(1).length() > 93)
             {
-                const QString val(rxH.cap(1).remove(_leading_non_letters));
+                const QString val(c2bUtils::removed(rxH.cap(1), _leading_non_letters));
                 _current_reference[_abstract] = _bpP->parse(_abstract, val);
                 return;
             }
@@ -225,7 +225,7 @@ void heuristicBibParser::guessAbstract(const QString& text)
         nH = rxH.indexIn(text);
         if (nH > -1)
         {
-            const QString val(rxH.cap(1).remove(_leading_non_letters));
+            const QString val(c2bUtils::removed(rxH.cap(1), _leading_non_letters));
             _current_reference[_abstract] = _bpP->parse(_abstract, val);
             return;
         }
@@ -239,7 +239,7 @@ void heuristicBibParser::guessAbstract(const QString& text)
         if (nH > -1)
             if (rxH.cap(1).length() > 93)
             {
-                const QString val(rxH.cap(1).remove(_leading_non_letters));
+                const QString val(c2bUtils::removed(rxH.cap(1), _leading_non_letters));
                 _current_reference[_abstract] = _bpP->parse(_abstract, val);
                 return;
             }
@@ -250,7 +250,7 @@ void heuristicBibParser::guessAbstract(const QString& text)
         nH = rxH.indexIn(text);
         if (nH > -1)
         {
-            const QString val(rxH.cap(1).remove(_leading_non_letters));
+            const QString val(c2bUtils::removed(rxH.cap(1), _leading_non_letters));
             _current_reference[_abstract] = _bpP->parse(_abstract, val);
             return;
         }
@@ -260,7 +260,7 @@ void heuristicBibParser::guessAbstract(const QString& text)
         if (nH > -1)
             if (rxH.cap(1).length() > 93)
             {
-                const QString val(rxH.cap(1).remove(_leading_non_letters));
+                const QString val(c2bUtils::removed(rxH.cap(1), _leading_non_letters));
                 _current_reference[_abstract] = _bpP->parse(_abstract, val);
                 return;
             }
@@ -270,7 +270,7 @@ void heuristicBibParser::guessAbstract(const QString& text)
         nH = rxH.indexIn(text);
         if (nH > -1)
         {
-            const QString val(rxH.cap(1).remove(_leading_non_letters));
+            const QString val(c2bUtils::removed(rxH.cap(1), _leading_non_letters));
             _current_reference[_abstract] = _bpP->parse(_abstract, val);
             return;
         }
@@ -294,16 +294,16 @@ void heuristicBibParser::guessAuthor(const QString& tagged_text)
     simplified_text.replace('|', ' ');
     simplified_text = "| " + simplified_text + " |";
 
-    simplified_text.replace(QRegExp("<NewLine\\d+>"), " | ");
-    simplified_text.replace(QRegExp("(\\w)<Tab\\d+>(\\w)"), "\\1 , \\2");
-    simplified_text.replace(QRegExp("<Tab\\d+>"), " ");
+    c2bUtils::replace(simplified_text, QRegExp("<NewLine\\d+>"), " | ");
+    c2bUtils::replace(simplified_text, QRegExp("(\\w)<Tab\\d+>(\\w)"), "\\1 , \\2");
+    c2bUtils::replace(simplified_text, QRegExp("<Tab\\d+>"), " ");
 
-    simplified_text.remove(QRegExp("author.{0,3}:{0,1}", Qt::CaseInsensitive));
-    simplified_text.replace(QRegExp("(\\w{4,10})[a-z]\\)", Qt::CaseSensitive),
-                            "\\1 "); // Remove superscript, e. g. LASTNAMEa
-    simplified_text.replace(QRegExp("([A-Z]{2,10})[a-z]\\b", Qt::CaseSensitive),
-                            "\\1 "); // Remove superscript, e. g. LASTNAMEa)
-    simplified_text.replace(_hyphens, "-");
+    c2bUtils::remove(simplified_text, QRegExp("author.{0,3}:{0,1}", Qt::CaseInsensitive));
+    c2bUtils::replace(simplified_text, QRegExp("(\\w{4,10})[a-z]\\)", Qt::CaseSensitive),
+                      "\\1 "); // Remove superscript, e. g. LASTNAMEa
+    c2bUtils::replace(simplified_text, QRegExp("([A-Z]{2,10})[a-z]\\b", Qt::CaseSensitive),
+                      "\\1 "); // Remove superscript, e. g. LASTNAMEa)
+    c2bUtils::replace(simplified_text, _hyphens, "-");
     simplified_text.replace(QChar(183), ',');               // Fancy author separator
     simplified_text.replace(' ' + QChar(198) + ' ', " , "); // Fancy author separator
     simplified_text.replace(QChar(8226), ',');              // Fancy author separator
@@ -401,7 +401,7 @@ void heuristicBibParser::guessKeywords(const QString& text)
     int nH(rxH.indexIn(text));
     if (nH > -1)
     {
-        const QString val(rxH.cap(1).remove(_leading_non_letters));
+        const QString val(c2bUtils::removed(rxH.cap(1), _leading_non_letters));
         _current_reference[_keywords] = _bpP->parse(_keywords, val);
         return;
     }
@@ -410,7 +410,7 @@ void heuristicBibParser::guessKeywords(const QString& text)
     nH = rxH.indexIn(text);
     if (nH > -1)
     {
-        const QString val(rxH.cap(1).remove(_leading_non_letters));
+        const QString val(c2bUtils::removed(rxH.cap(1), _leading_non_letters));
         _current_reference[_keywords] = _bpP->parse(_keywords, val);
     }
 
@@ -420,7 +420,7 @@ void heuristicBibParser::guessKeywords(const QString& text)
     nH = rxH.indexIn(text);
     if (nH > -1)
     {
-        const QString val(rxH.cap(1).remove(_leading_non_letters));
+        const QString val(c2bUtils::removed(rxH.cap(1), _leading_non_letters));
         _current_reference[_keywords] = _bpP->parse(_keywords, val);
         return;
     }
@@ -429,7 +429,7 @@ void heuristicBibParser::guessKeywords(const QString& text)
     nH = rxH.indexIn(text);
     if (nH > -1)
     {
-        const QString val(rxH.cap(1).remove(_leading_non_letters));
+        const QString val(c2bUtils::removed(rxH.cap(1), _leading_non_letters));
         _current_reference[_keywords] = _bpP->parse(_keywords, val);
     }
 }
@@ -602,7 +602,7 @@ void heuristicBibParser::guessPages(const QString& text)
             if (!rxH.cap(1).startsWith('0'))
             {
                 const QString pp(_bpP->parse(_pages, QString("%1 %2").arg(rxH.cap(1), rxH.cap(2))));
-                const QStringList flpp(pp.split(QRegExp("\\D"), _QT_6_SkipEmptyParts));
+                const QStringList flpp(c2bUtils::split(pp, QRegExp("\\D"), _QT_6_SkipEmptyParts));
                 if (flpp.count() != 2)
                     continue;
                 const int fp(flpp.first().toInt());
@@ -674,7 +674,7 @@ void heuristicBibParser::guessTitle(const QString& text)
     int nH(rxH.indexIn(text));
     if (nH > -1)
     {
-        QString val(rxH.cap(1).remove(_leading_non_letters));
+        const QString val(c2bUtils::removed(rxH.cap(1), _leading_non_letters));
         _current_reference[_title] = _bpP->parse(_title, val);
         return;
     }
@@ -683,7 +683,7 @@ void heuristicBibParser::guessTitle(const QString& text)
     nH = rxH.indexIn(text);
     if (nH > -1)
     {
-        QString val(rxH.cap(1).remove(_leading_non_letters));
+        const QString val(c2bUtils::removed(rxH.cap(1), _leading_non_letters));
         _current_reference[_title] = _bpP->parse(_title, val);
     }
 }
@@ -722,7 +722,7 @@ void heuristicBibParser::guessISBN(const QString& text)
 void heuristicBibParser::guessJournal(const QString& text)
 {
     QString stext(text.toLower());
-    stext.remove(c2bUtils::nonLetter);
+    c2bUtils::remove(stext, c2bUtils::nonLetter);
     if (stext.length() < 3 || stext.length() > 10000)
         return;
 
