@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "journalDB.h"
@@ -28,7 +28,11 @@ journalDB::journalDB(const QString& dbfile)
         return;
     }
     QTextStream stream(&file);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    stream.setEncoding(QStringConverter::Utf8);
+#else
     stream.setCodec("UTF-8");
+#endif
     stream.setAutoDetectUnicode(true);
     QString line;
     int line_number(0);
@@ -73,9 +77,9 @@ journalDB::journalDB(const QString& dbfile)
     for (int i = 0; i < _nitems; ++i)
     {
         JAbbrev_simp[i] = JAbbrev.at(i).toLower();
-        JAbbrev_simp[i].remove(c2bUtils::nonLetter);
+        c2bUtils::remove(JAbbrev_simp[i], c2bUtils::nonLetter);
         JExtended_simp[i] = JExtended.at(i).toLower();
-        JExtended_simp[i].remove(c2bUtils::nonLetter);
+        c2bUtils::remove(JExtended_simp[i], c2bUtils::nonLetter);
     }
 }
 
@@ -147,7 +151,7 @@ AN|Am. Nat.=Amer. Naturalist|American Naturalist=The American Naturalist
 */
 QString journalDB::retrieve(const QString& JQuery) const
 {
-    const QString query(JQuery.toLower().remove(c2bUtils::nonLetter));
+    const QString query(c2bUtils::removed(JQuery.toLower(), c2bUtils::nonLetter));
     if (query.isEmpty())
         return QString();
     for (int i = 0; i < _nitems; ++i)
@@ -178,7 +182,7 @@ QString journalDB::retrieve(const QString& JQuery) const
 
 QString journalDB::retrieveFull(const QString& JQuery) const
 {
-    const QString query(JQuery.toLower().remove(c2bUtils::nonLetter));
+    const QString query(c2bUtils::removed(JQuery.toLower(), c2bUtils::nonLetter));
     if (query.isEmpty())
         return QString();
     for (int i = 0; i < _nitems; ++i)
@@ -211,7 +215,7 @@ QString journalDB::retrieveFull(const QString& JQuery) const
 
 QString journalDB::retrieveAlternate(const QString& JQuery) const
 {
-    const QString query(JQuery.toLower().remove(c2bUtils::nonLetter));
+    const QString query(c2bUtils::removed(JQuery.toLower(), c2bUtils::nonLetter));
     if (query.isEmpty())
         return QString();
     for (int i = _nitems - 1; i >= 0; --i)
@@ -247,7 +251,7 @@ QString journalDB::retrieveAlternate(const QString& JQuery) const
 
 QString journalDB::retrieveAlternateFull(const QString& JQuery) const
 {
-    const QString query(JQuery.toLower().remove(c2bUtils::nonLetter));
+    const QString query(c2bUtils::removed(JQuery.toLower(), c2bUtils::nonLetter));
     if (query.isEmpty())
         return QString();
     for (int i = _nitems - 1; i >= 0; --i)
