@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "metadataParser.h"
@@ -365,7 +365,7 @@ void metadataParser::_fuzzyParser(const QString& data)
                 value = att.at(i).value().toString();
                 if (value.isEmpty())
                     continue;
-                if (field.contains(*fields))
+                if (fields->indexIn(field) >= 0)
                     _ref[_bibtex_key.value(key)] = value;
                 else if (QString::compare(field, "summary", Qt::CaseInsensitive) == 0 ||
                          QString::compare(field, "subject", Qt::CaseInsensitive) == 0)
@@ -381,7 +381,7 @@ void metadataParser::_fuzzyParser(const QString& data)
             // Do element (exiftool and exempi xml composing)
             field = parser.qualifiedName().toString();
             key = parser.name().toString().toLower();
-            if (field.contains(*fields))
+            if (fields->indexIn(field) >= 0)
             {
                 parser.readNext();
                 value = parser.text().toString().trimmed();
