@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "network.h"
@@ -91,7 +91,7 @@ void network::getFilePrivate(const Action action)
     }
     if (_source_filename.startsWith("<<post>>")) // cb2Bib keyword to use post http method
     {
-        _source_filename.remove(QRegExp("^<<post>>"));
+        c2bUtils::remove(_source_filename, QRegExp("^<<post>>"));
         _fetch_c2b(action, QNetworkAccessManager::PostOperation);
         return;
     }
@@ -344,7 +344,11 @@ void network::_fetch(const QUrl& url)
         _current_reply = _fetcher->get(request);
     connect(_current_reply, SIGNAL(readyRead()), this, SLOT(_fetch_ready_read()));
     connect(_current_reply, SIGNAL(finished()), SLOT(_fetch_finished()));
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+    connect(_current_reply, SIGNAL(errorOccurred(QNetworkReply::NetworkError)), this, SLOT(logError()));
+#else
     connect(_current_reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(logError()));
+#endif
     connect(_current_reply, SIGNAL(downloadProgress(qint64,qint64)), this, SIGNAL(downloadProgress(qint64,qint64)));
 }
 
