@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "networkQuery.h"
@@ -58,20 +58,20 @@ void networkQuery::submitQuery(const bibReference& reference, const QString& raw
     _Qvolume = reference.value("volume");
     _Qpage = c2bUtils::firstPage(reference.value("pages"));
     _Qdoi = reference.value("doi").trimmed();
-    if (!_Qdoi.isEmpty() && !_Qdoi.contains(QRegExp("^10\\.[\\d\\.]+/\\S+$")))
+    if (!_Qdoi.isEmpty() && QRegExp("^10\\.[\\d\\.]+/\\S+$").indexIn(_Qdoi) == -1)
     {
         _Qdoi.clear();
         c2bUtils::warn(tr("Warning: DOI skipped: '%1' is not a valid DOI").arg(_Qdoi));
     }
     _Qauthor = reference.value("author");
-    _Qauthor.replace(QRegExp("(?:\\b\\w\\b|\\band\\b|\\W)"), " ");
+    _Qauthor = c2bUtils::replaced(_Qauthor, QRegExp("(?:\\b\\w\\b|\\band\\b|\\W)"), " ");
     _Qauthor = c2bUtils::simplifyString(_Qauthor);
     _Qexcerpt = _bpP->excerpt(raw_reference, QStringList() << _Qdoi << _Qauthor << _Qtitle);
     _Qeprint = reference.value("eprint").trimmed();
 
     _raw_reference = raw_reference;
     // Remove raw metadata in case user repeats the network query
-    _raw_reference.remove(QRegExp("\\n\\[Raw Metadata.+$"));
+    c2bUtils::remove(_raw_reference, QRegExp("\\n\\[Raw Metadata.+$"));
 
     if (_timing.msecsTo(QDateTime::currentDateTime()) < 550)
         QTimer::singleShot(550, this, SLOT(submitQuery1()));
@@ -205,7 +205,7 @@ void networkQuery::submitQuery2(bool succeeded)
 void networkQuery::submitQuery3(bool succeeded)
 {
     // Submission, third part: extracting reference location
-    if (!succeeded || !_networkP->mimetypeString().contains(QRegExp("\\b(chm|djvu|pdf|ps)\\b")))
+    if (!succeeded || QRegExp("\\b(chm|djvu|pdf|ps)\\b").indexIn(_networkP->mimetypeString()) == -1)
         _targetPDF.clear();
     else
         _targetPDF = _networkP->sourceFilename();
@@ -269,9 +269,17 @@ bool networkQuery::setQueryParameters()
         return false;
 
     QFile file(_settingsP->fileName("cb2Bib/NetworkFile"));
-    file.open(QIODevice::ReadOnly | QIODevice::Text);
+    if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
+    {
+        c2bUtils::warn(tr("Failed to open '%1' file.").arg(_settingsP->fileName("cb2Bib/NetworkFile")));
+        return false;
+    }
     QTextStream stream(&file);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    stream.setEncoding(QStringConverter::Utf8);
+#else
     stream.setCodec("UTF-8");
+#endif
     stream.setAutoDetectUnicode(true);
     QRegExp Journal("journal=" + _Qjournal + "\\|");
     QRegExp AnyJournal("journal=\\s*$");
@@ -284,9 +292,9 @@ bool networkQuery::setQueryParameters()
         if (line.startsWith("%c2b_stop_parsing"))
             break;
         // Skip comments and blanks
-        if (!(line.isEmpty() || line.contains(QRegExp("^#"))))
+        if (!(line.isEmpty() || QRegExp("^#").indexIn(line) >= 0))
         {
-            if (line.contains(Journal))
+            if (Journal.indexIn(line) >= 0)
             {
                 const QStringList lc(line.split('|'));
                 if (lc.count() > 1)
@@ -294,35 +302,35 @@ bool networkQuery::setQueryParameters()
                 else
                     _QjournalCode.clear();
             }
-            else if (line.contains(AnyJournal))
+            else if (AnyJournal.indexIn(line) >= 0)
             {
                 _QjournalCode = _Qjournal;
                 _QjournalCode.replace(" & ", " and "); // Avoid sending '&' to confuse URLs
-                _QjournalCode.replace(QRegExp("\\W"), " ");
+                _QjournalCode = c2bUtils::replaced(_QjournalCode, QRegExp("\\W"), " ");
                 _QjournalCode = _QjournalCode.simplified();
                 _QjournalCode.replace(" ", "+");
             }
             // Get appropiate parameters for Journal or AnyJournal
-            if (line.contains(Journal) || line.contains(AnyJournal))
+            if (Journal.indexIn(line) >= 0 || AnyJournal.indexIn(line) >= 0)
             {
                 // Skip if already performed
                 if (!_query_parameter_count.contains(++readQueryParams))
                 {
-                    while (line.contains(QRegExp("^journal=")))
+                    while (QRegExp("^journal=").indexIn(line) >= 0)
                         line = stream.readLine();
-                    _targetQ = line.remove(QRegExp("^query="));
+                    _targetQ = c2bUtils::removed(line, QRegExp("^query="));
                     line = stream.readLine();
-                    _captionQ = line.remove(QRegExp("^capture_from_query="));
+                    _captionQ = c2bUtils::removed(line, QRegExp("^capture_from_query="));
                     line = stream.readLine();
-                    _referenceurl_prefix = line.remove(QRegExp("^referenceurl_prefix="));
+                    _referenceurl_prefix = c2bUtils::removed(line, QRegExp("^referenceurl_prefix="));
                     line = stream.readLine();
-                    _referenceurl_sufix = line.remove(QRegExp("^referenceurl_sufix="));
+                    _referenceurl_sufix = c2bUtils::removed(line, QRegExp("^referenceurl_sufix="));
                     line = stream.readLine();
-                    _pdfurl_prefix = line.remove(QRegExp("^pdfurl_prefix="));
+                    _pdfurl_prefix = c2bUtils::removed(line, QRegExp("^pdfurl_prefix="));
                     line = stream.readLine();
-                    _pdfurl_sufix = line.remove(QRegExp("^pdfurl_sufix="));
+                    _pdfurl_sufix = c2bUtils::removed(line, QRegExp("^pdfurl_sufix="));
                     line = stream.readLine();
-                    _action = line.remove(QRegExp("^action="));
+                    _action = c2bUtils::removed(line, QRegExp("^action="));
                     // Setting Query Parameters
                     updateQueryPlaceholders();
                     // Finally, check for unresolved cb2Bib tags
@@ -409,7 +417,7 @@ void networkQuery::updateQueryPlaceholders()
     _pdfurl_is_captured = (pdfurl_prefix != _pdfurl_prefix);
 }
 
-bool networkQuery::areQueryParametersValid()
+bool networkQuery::areQueryParametersValid() const
 {
     if (!_action.isEmpty())
     {
@@ -424,15 +432,14 @@ bool networkQuery::areQueryParametersValid()
     }
     const QString allParams(_targetQ + _captionQ + _referenceurl_prefix + _referenceurl_sufix + _pdfurl_prefix +
                             _pdfurl_sufix);
-    return !(
-               allParams.contains(QRegExp("(?:<<title>>|<<journal>>|<<pages>>|<<volume>>|<<doi>>|<<excerpt>>|<<eprint>>)")));
+    return QRegExp("(?:<<title>>|<<journal>>|<<pages>>|<<volume>>|<<doi>>|<<excerpt>>|<<eprint>>)")
+           .indexIn(allParams) == -1;
 }
 
 const QString networkQuery::encodeUrl(const QString& url) const
 {
     // Removes <<post>> tag if present and encodes URL to percent encoding
-    QString encoded_url(url);
-    encoded_url.remove(QRegExp("^<<post>>"));
+    QString encoded_url(c2bUtils::removed(url, QRegExp("^<<post>>")));
     encoded_url = QUrl::toPercentEncoding(encoded_url, "+:/?=&\\");
     return encoded_url;
 }
