@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef NETWORKQUERY_H
@@ -65,6 +65,12 @@ protected:
 
 
 private:
+    bool areQueryParametersValid() const;
+    bool setQueryParameters();
+    const QString encodeUrl(const QString& url) const;
+    void init();
+    void updateQueryPlaceholders();
+
     QDateTime _timing;
     QList<uint> _query_parameter_count;
     QString _Qauthor;
@@ -94,20 +100,15 @@ private:
     bool _check_document;
     bool _is_end_of_file;
     bool _pdfurl_is_captured;
-    const QString encodeUrl(const QString& url) const;
     network* _networkP;
     settings* _settingsP;
-    void init();
 
 
 private slots:
-    bool areQueryParametersValid();
-    bool setQueryParameters();
     void queryDone(bool succeeded);
     void submitQuery1();
     void submitQuery2(bool succeeded);
     void submitQuery3(bool succeeded);
-    void updateQueryPlaceholders();
 };
 
 #endif
