@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "posTagger.h"
@@ -51,7 +51,11 @@ bool posTagger::loadLexicon()
         return false;
     }
     QTextStream lex(&lexf);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    lex.setEncoding(QStringConverter::Utf8);
+#else
     lex.setCodec("UTF-8");
+#endif
     lex.setAutoDetectUnicode(true);
     const QChar comment('#');
     QString line;
