@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "pubmedXml.h"
@@ -23,30 +23,30 @@ void pubmedXml::readReference()
         return;
 
     while (reading("PubmedArticle"))
-        if (name() == "Journal")
+        if (name().toLatin1() == "Journal")
             readJournal();
-        else if (name() == "AuthorList")
+        else if (name().toLatin1() == "AuthorList")
             readAuthors();
-        else if (name() == "MeshHeadingList")
+        else if (name().toLatin1() == "MeshHeadingList")
             readKeywords();
-        else if (name() == "ArticleTitle")
+        else if (name().toLatin1() == "ArticleTitle")
             readField("title");
-        else if (name() == "AbstractText")
+        else if (name().toLatin1() == "AbstractText")
             readField("abstract");
-        else if (name() == "MedlinePgn")
+        else if (name().toLatin1() == "MedlinePgn")
         {
             readNext();
-            _reference["pages"] = text().toString().remove(QRegExp("\\,[\\s\\d]+")); // Cases "11-5, 25"
+            _reference["pages"] = c2bUtils::removed(text().toString(), QRegExp("\\,[\\s\\d]+")); // Cases "11-5, 25"
         }
-        else if (name() == "PMID")
+        else if (name().toLatin1() == "PMID")
         {
             readNext();
             _reference["url"] = c2bUtils::pubmedUrl.arg(text().toString());
         }
-        else if (name() == "ArticleId")
+        else if (name().toLatin1() == "ArticleId")
         {
             if (attributes().count() > 0)
-                if (attributes().at(0).value().toString() == "doi")
+                if (attributes().at(0).value().toLatin1() == "doi")
                     readField("doi");
         }
 }
@@ -61,33 +61,33 @@ void pubmedXml::readAuthors()
     QStringList authors;
     while (reading("AuthorList"))
     {
-        if (name() == "Author" && attributes().value("ValidYN") != "N")
+        if (name().toLatin1() == "Author" && attributes().value("ValidYN").toLatin1() != "N")
         {
             QString a, i;
             bool abbreviated(true);
             while (reading("Author"))
-                if (name() == "LastName")
+                if (name().toLatin1() == "LastName")
                 {
                     readNext();
                     a = a + ' ' + text().toString();
                 }
-                else if (name() == "ForeName" || name() == "FirstName")
+                else if (name().toLatin1() == "ForeName" || name().toLatin1() == "FirstName")
                 {
                     readNext();
                     a = text().toString() + ' ' + a;
                     abbreviated = false;
                 }
-                else if (name() == "Suffix")
+                else if (name().toLatin1() == "Suffix")
                 {
                     readNext();
-                    if (text() == "2nd")
+                    if (text().toLatin1() == "2nd")
                         a = a + " II";
-                    else if (text() == "3rd")
+                    else if (text().toLatin1() == "3rd")
                         a = a + " III";
                     else
                         a = a + ' ' + text().toString();
                 }
-                else if (name() == "Initials")
+                else if (name().toLatin1() == "Initials")
                 {
                     readNext();
                     i = text().toString();
@@ -105,23 +105,23 @@ void pubmedXml::readJournal()
 {
     QString ja, jf, mldate;
     while (reading("Journal"))
-        if (name() == "ISOAbbreviation")
+        if (name().toLatin1() == "ISOAbbreviation")
         {
             readNext();
             ja = text().toString();
         }
-        else if (name() == "Title")
+        else if (name().toLatin1() == "Title")
         {
             readNext();
             jf = text().toString();
         }
-        else if (name() == "Volume")
+        else if (name().toLatin1() == "Volume")
             readField("volume");
-        else if (name() == "Issue")
+        else if (name().toLatin1() == "Issue")
             readField("number");
-        else if (name() == "Year")
+        else if (name().toLatin1() == "Year")
             readField("year");
-        else if (name() == "MedlineDate")
+        else if (name().toLatin1() == "MedlineDate")
         {
             readNext();
             mldate = text().toString();
@@ -132,8 +132,8 @@ void pubmedXml::readJournal()
         _reference["journal"] = jf;
     if (_reference.value("year").isEmpty())
     {
-        mldate.remove(QRegExp("[^\\d\\s-]"));
-        mldate.remove(QRegExp("\\b\\d{1,3}\\b"));
+        c2bUtils::remove(mldate, QRegExp("[^\\d\\s-]"));
+        c2bUtils::remove(mldate, QRegExp("\\b\\d{1,3}\\b"));
         _reference["year"] = mldate;
     }
 }
@@ -142,7 +142,7 @@ void pubmedXml::readKeywords()
 {
     QStringList k;
     while (reading("MeshHeadingList"))
-        if (name() == "DescriptorName")
+        if (name().toLatin1() == "DescriptorName")
         {
             readNext();
             k.append(text().toString());
