@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "stemMatcher.h"
@@ -60,7 +60,7 @@ void stemMatcher::setPattern(const QString& pattern, const Qt::CaseSensitivity c
 
             for (int o = 0; o < qors.count(); ++o)
             {
-                slength = std::max(slength, qors.at(o).length());
+                slength = std::max(slength, int(qors.at(o).length()));
                 const QStringList words(qors.at(o).split(QLatin1Char('_'), _QT_6_SkipEmptyParts));
                 QStringList sw;
                 for (int w = 0; w < words.count(); ++w)
@@ -70,7 +70,7 @@ void stemMatcher::setPattern(const QString& pattern, const Qt::CaseSensitivity c
                         mpls.add(s, o, words.at(w).length() - 1, words.at(w).length() - 1);
                         if (words.count() == 1)
                             mpls.blankspaces -= 1;
-                        bw.replace(c2bUtils::nonLetter, stretcht.arg(1));
+                        c2bUtils::replace(bw, c2bUtils::nonLetter, stretcht.arg(1));
                         sw.append(boundedt.arg(bw));
                     }
                     else
@@ -88,9 +88,9 @@ void stemMatcher::setPattern(const QString& pattern, const Qt::CaseSensitivity c
 
                         for (int l = 0; l < wl.count(); ++l)
                         {
-                            const int nnl(wl.at(l).count(c2bUtils::nonLetter));
+                            const int nnl(c2bUtils::count(wl.at(l), c2bUtils::nonLetter));
                             if (nnl > 0 && nnl < wl.at(l).length())
-                                wl[l].replace(c2bUtils::nonLetter, stretcht.arg(1));
+                                c2bUtils::replace(wl[l], c2bUtils::nonLetter, stretcht.arg(1));
                         }
                         sw.append(wl.count() == 1 ? wl.at(0) : ort.arg(wl.join('|')));
                     }
@@ -102,13 +102,13 @@ void stemMatcher::setPattern(const QString& pattern, const Qt::CaseSensitivity c
         }
 
         mpls.cleanup();
-        _subpatterns = pattern.split(rmnww, _QT_6_SkipEmptyParts);
+        _subpatterns = c2bUtils::split(pattern, rmnww, _QT_6_SkipEmptyParts);
     }
 
     _substring_count = substrings.count();
     _substring_rex_count = 0;
     for (int i = 0; i < _substring_count; ++i)
-        if (substrings.at(i).contains(c2bUtils::nonLetter))
+        if (c2bUtils::nonLetter.indexIn(substrings.at(i)) >= 0)
             ++_substring_rex_count;
     _substring_txt_count = _substring_count - _substring_rex_count;
     _substrings_rex.resize(_substring_rex_count);
@@ -118,10 +118,10 @@ void stemMatcher::setPattern(const QString& pattern, const Qt::CaseSensitivity c
     _signature_string.clear();
 
     for (int i = 0, ir = 0, it = 0; i < _substring_count; ++i)
-        if (substrings.at(i).contains(c2bUtils::nonLetter))
+        if (c2bUtils::nonLetter.indexIn(substrings.at(i)) >= 0)
         {
             QRegularExpression& re(_substrings_rex[ir++]);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0) & QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             const QRegularExpression::PatternOptions po(QRegularExpression::DontCaptureOption |
                     QRegularExpression::UseUnicodePropertiesOption |
                     QRegularExpression::OptimizeOnFirstUsageOption);
