@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "texParser.h"
@@ -79,7 +79,7 @@ void texParser::gotoEnd(const QString& e)
     while (!_stream.atEnd())
     {
         readLine();
-        if (_line.contains(end_block))
+        if (end_block.indexIn(_line) >= 0)
         {
             _element += '\n' + _line.trimmed();
             break;
