@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "texToHtml.h"
@@ -255,10 +255,10 @@ void texToHtml::citesToHtml(QString* html)
     while (i != _references.constEnd())
     {
         const QString k(i.key());
-        html->replace(QRegExp(key.arg(k)), QString("<a href=\"#%1\">%2</a>").arg(k).arg(_cites.value(k)));
+        c2bUtils::replace(*html, QRegExp(key.arg(k)), QString("<a href=\"#%1\">%2</a>").arg(k).arg(_cites.value(k)));
         ++i;
     }
-    html->replace(QRegExp("\\\\cite\\{([^\\{]+)\\}"), "<span class=\"citations\">[\\1]</span>");
+    c2bUtils::replace(*html, QRegExp("\\\\cite\\{([^\\{]+)\\}"), "<span class=\"citations\">[\\1]</span>");
 }
 
 /**
@@ -329,7 +329,7 @@ void texToHtml::referencesToHtml(QString* reference_list_html)
         if (!author.isEmpty())
         {
             author = _cbp.authorFromBibTeX(author);
-            author.remove(nonletters);
+            c2bUtils::remove(author, nonletters);
             author.replace(" and ", ", ");
             c2bUtils::simplifyString(author);
             author += '.';
