@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "triads.h"
@@ -30,7 +30,7 @@ const QVector<QString> triads::textSignature(const QStringList& strs)
 const QString triads::asciiTextSignature(const QString& str)
 {
     QString s(str);
-    s.replace(c2bUtils::nonAsciiLetter, " ");
+    c2bUtils::replace(s, c2bUtils::nonAsciiLetter, " ");
     s = s.toLower();
 
     const int nletters(26);
@@ -42,7 +42,7 @@ const QString triads::asciiTextSignature(const QString& str)
     QSet<int> triads;
     for (int i = 0; i <= slength - ngram; ++i)
     {
-        if (s.midRef(i, ngram).contains(space))
+        if (s.mid(i, ngram).contains(space))
             continue;
         const int t1(s.at(i).unicode() - code0);
         const int t2(s.at(i + 2).unicode() - code0);
