@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "wordMatcher.h"
@@ -26,7 +26,7 @@ void wordMatcher::setPattern(const QString& pattern, const Qt::CaseSensitivity c
     _matched_length = -1;
     _stretch = 0;
 
-    _subpatterns = pattern.split(c2bUtils::nonLetter, _QT_6_SkipEmptyParts);
+    _subpatterns = c2bUtils::split(pattern, c2bUtils::nonLetter, _QT_6_SkipEmptyParts);
     if (_subpatterns.count() == 0)
         return;
     _substring_count = _subpatterns.count();
