@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "wordPattern.h"
@@ -27,7 +27,7 @@ void wordPattern::setPattern(const QString& pattern, const Type type, const Qt::
     _is_multipattern = false;
     _matched_length = -1;
 
-    const QStringList words(_string.split(c2bUtils::nonLetter, _QT_6_SkipEmptyParts));
+    const QStringList words(c2bUtils::split(_string, c2bUtils::nonLetter, _QT_6_SkipEmptyParts));
     _subpattern_count = words.count();
     if (_subpattern_count == 0)
         return;
