@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bAnnote.h"
@@ -16,6 +16,7 @@
 
 #include <QLabel>
 #include <QMessageBox>
+#include <QRegularExpression>
 #include <QShortcut>
 #include <QStatusBar>
 
@@ -119,7 +120,7 @@ bool c2bAnnote::show()
     _annote_filename = QDir::cleanPath(_settingsP->cl_annote_filename);
     const bool is_html = _annote_filename.endsWith(".html");
     if (is_html)
-        _annote_filename.remove(QRegExp("\\.html$"));
+        _annote_filename.remove(QRegularExpression("\\.html$"));
     if (!QFileInfo::exists(_annote_filename))
     {
         QMessageBox::warning(this, tr("Warning - cb2Bib"),
