@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bCitePatternLineEedit.h"
@@ -52,7 +52,7 @@ c2bCitePatternLineEedit::~c2bCitePatternLineEedit() {}
 
 void c2bCitePatternLineEedit::check(const QString& pattern)
 {
-    if (!pattern.isEmpty() && ((!pattern.contains(_citeids) && !pattern.contains(QLatin1String("<<citeid>>"))) ||
+    if (!pattern.isEmpty() && ((_citeids.indexIn(pattern) == -1 && !pattern.contains(QLatin1String("<<citeid>>"))) ||
                                pattern.count(QLatin1String("citeid")) > 1))
         emit statusMessage(tr("Cite Command Pattern is misspecified"));
     else
