@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bCiterModel.h"
@@ -125,7 +125,7 @@ void c2bCiterModel::setPatternFilter(const QString& pattern, QModelIndex* curren
 {
     _history.saveCurrentState(_format, _filter, _current_item(current_index), current_index, _fstring);
     emit layoutAboutToBeChanged();
-    const QStringList word(pattern.split(c2bUtils::nonLetter, _QT_6_SkipEmptyParts));
+    const QStringList word(c2bUtils::split(pattern, c2bUtils::nonLetter, _QT_6_SkipEmptyParts));
     _filter = word.count() > 0 ? c2bCiter::Pattern : c2bCiter::None;
     _format = format;
     if (_filter == c2bCiter::Pattern)
@@ -571,8 +571,8 @@ void c2bCiterModel::_add_citations(const QString& fn)
         if (!author.isEmpty())
         {
             author = bpP->authorFromBibTeX(author);
-            author.remove(initials1);
-            author.remove(initials2);
+            c2bUtils::remove(author, initials1);
+            c2bUtils::remove(author, initials2);
             author.replace(" and ", ", ");
             c2bUtils::simplifyString(author);
         }
@@ -600,7 +600,9 @@ void c2bCiterModel::_add_citations(const QString& fn)
         uint included_date;
         const QFileInfo finf(file);
         if (finf.exists())
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+            included_date = finf.lastModified().date().startOfDay().toSecsSinceEpoch();
+#elif QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
             included_date = finf.lastModified().date().startOfDay().toTime_t();
 #else
             included_date = QDateTime(finf.lastModified().date()).toTime_t();
@@ -685,7 +687,7 @@ void c2bCiterModel::_set_table_data()
         {
             _author[ij] = authors.at(j).trimmed();
             _map_author[ij] = i;
-            _author_max_length = std::max(_author_max_length, _author.at(ij).length());
+            _author_max_length = std::max(_author_max_length, int(_author.at(ij).length()));
             ++ij;
         }
     }
@@ -697,7 +699,7 @@ void c2bCiterModel::_set_table_data()
     {
         _journal[i] = bpP->abbreviatedJournal(_journal.at(i));
         _journal[i].remove(dot);
-        _journal_max_length = std::max(_journal_max_length, _journal.at(i).length());
+        _journal_max_length = std::max(_journal_max_length, int(_journal.at(i).length()));
     }
 
     _is_selected.resize(_citation_count);
@@ -732,7 +734,11 @@ void c2bCiterModel::_set_sort_indices()
 
     // IT
     _search_string.resize(_citation_count);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    const qint64 current_dtt(QDateTime::currentDateTime().toSecsSinceEpoch());
+#else
     const int current_dtt(QDateTime::currentDateTime().toTime_t());
+#endif
     const QString dtt("%1");
     const QChar padding('0');
     for (int i = 0; i < _citation_count; ++i)
@@ -858,9 +864,15 @@ QString c2bCiterModel::_display_it(const int row, const int column) const
     switch (column)
     {
     case 0:
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        return _included_date.at(_offset(row)) > 0
+               ? QDateTime::fromSecsSinceEpoch(_included_date.at(_offset(row))).date().toString(Qt::ISODate)
+               : QString();
+#else
         return _included_date.at(_offset(row)) > 0
                ? QDateTime::fromTime_t(_included_date.at(_offset(row))).date().toString(Qt::ISODate)
                : QString();
+#endif
     case 1:
         return _title.at(_offset(row));
     default:
