@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bCiterWidget.h"
@@ -154,7 +154,11 @@ void c2bCiterWidget::setActions()
     connect(a, SIGNAL(triggered()), this, SLOT(openDirectory()));
     a = new QAction(this);
     a->setText(tr("Open Files"));
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    a->setShortcut(QKeySequence(Qt::ALT | Qt::Key_O));
+#else
     a->setShortcut(QKeySequence(Qt::ALT + Qt::Key_O));
+#endif
     addAction(a);
     connect(a, SIGNAL(triggered()), this, SLOT(openFiles()));
     c2bUtils::addSeparator(this);
@@ -175,7 +179,11 @@ void c2bCiterWidget::setActions()
 
     a = new QAction(this);
     a->setText(tr("Set LyX Pipe"));
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    a->setShortcut(QKeySequence(Qt::ALT | Qt::Key_L));
+#else
     a->setShortcut(QKeySequence(Qt::ALT + Qt::Key_L));
+#endif
     addAction(a);
     connect(a, SIGNAL(triggered()), _citerP, SLOT(setLyXPipe()));
     c2bUtils::addSeparator(this);
@@ -187,12 +195,20 @@ void c2bCiterWidget::setActions()
     connect(a, SIGNAL(triggered()), this, SLOT(toggleCb2Bib()));
     a = new QAction(this);
     a->setText(tr("Toggle Clipboard"));
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    a->setShortcut(QKeySequence(Qt::ALT | Qt::Key_C));
+#else
     a->setShortcut(QKeySequence(Qt::ALT + Qt::Key_C));
+#endif
     addAction(a);
     connect(a, SIGNAL(triggered()), this, SLOT(toggleClipboard()));
     a = new QAction(this);
     a->setText(tr("Toggle Full Screen"));
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    a->setShortcut(QKeySequence(Qt::ALT | Qt::Key_F));
+#else
     a->setShortcut(QKeySequence(Qt::ALT + Qt::Key_F));
+#endif
     addAction(a);
     connect(a, SIGNAL(triggered()), this, SLOT(toggleFullScreen()));
     c2bUtils::addSeparator(this);
