@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bEditor.h"
@@ -494,7 +494,11 @@ bool c2bEditor::fileSave()
         return false;
     }
     QTextStream stream(&file);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    stream.setEncoding(QStringConverter::Utf8);
+#else
     stream.setCodec("UTF-8");
+#endif
     stream.setAutoDetectUnicode(true);
     stream << _editorP->toPlainText();
     ui.fileSaveAction->setEnabled(false);
@@ -549,7 +553,7 @@ void c2bEditor::load()
                 unamedList.append(widget->objectName());
         }
         int i(1);
-        while (unamedList.indexOf(QRegExp(QString(".*unnamed_%1.bib").arg(i))) > -1)
+        while (unamedList.indexOf(QRegularExpression(QString(".*unnamed_%1.bib").arg(i))) > -1)
             ++i;
         _editor_fn =
             QDir::toNativeSeparators(QDir::cleanPath(_editor_fn + QDir::separator() + QString("unnamed_%1.bib").arg(i)));
@@ -565,7 +569,7 @@ void c2bEditor::load()
         if (edit_ref_id.indexIn(_editor_fn) > -1)
         {
             _edit_reference_at_position = edit_ref_id.cap(1);
-            _editor_fn.remove(edit_ref_id);
+            c2bUtils::remove(_editor_fn, edit_ref_id);
         }
         QFile file(_editor_fn);
         if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
@@ -578,7 +582,11 @@ void c2bEditor::load()
         else
         {
             QTextStream stream(&file);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+            stream.setEncoding(QStringConverter::Utf8);
+#else
             stream.setCodec("UTF-8");
+#endif
             stream.setAutoDetectUnicode(true);
             _editorP->setPlainText(stream.readAll());
         }
@@ -760,6 +768,11 @@ void c2bEditor::showMessage(const QString& ms)
     statusBar()->showMessage(ms, C2B_MESSAGE_TIME);
 }
 
+void c2bEditor::showMessage(const QUrl& link)
+{
+    statusBar()->showMessage(link.toString(), C2B_MESSAGE_TIME);
+}
+
 void c2bEditor::cursorPositionChanged()
 {
     int ln, lp;
