@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BEDITOR_H
@@ -62,6 +62,11 @@ signals:
     void restartQuery();
 
 
+public slots:
+    void showMessage(const QString& ms);
+    void showMessage(const QUrl& link);
+
+
 protected:
     virtual void closeEvent(QCloseEvent* qevent);
 
@@ -87,7 +92,6 @@ protected slots:
     void reload(const QString& fn);
     void saveAndExecute();
     void setViewMode(bool edit_mode);
-    void showMessage(const QString& ms);
     void updateMetadata();
     void viewCb2Bib();
 
