@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bNetworkQueryInfo.h"
@@ -55,14 +55,18 @@ void c2bNetworkQueryInfo::parseBookmarks()
     QRegExp _bookmark("^bookmark=");
     QString line;
     QTextStream stream(&file);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    stream.setEncoding(QStringConverter::Utf8);
+#else
     stream.setCodec("UTF-8");
+#endif
     stream.setAutoDetectUnicode(true);
     while (!stream.atEnd())
     {
         line = stream.readLine();
-        if (line.contains(_bookmark))
+        if (_bookmark.indexIn(line) >= 0)
         {
-            line.remove(_bookmark);
+            c2bUtils::remove(line, _bookmark);
             if (line.count('|') == 0)
                 c2bUtils::warn(tr("c2bNetworkQueryInfo::parseBookmarks: Syntax error at '%1'").arg(line));
             else
@@ -74,7 +78,7 @@ void c2bNetworkQueryInfo::parseBookmarks()
         delete BookmarkActionList.takeFirst();
     const QRegExp rx("<<.+>>");
     for (int i = 0; i < BookmarkList.count(); ++i)
-        if (BookmarkList.at(i).contains(rx))
+        if (rx.indexIn(BookmarkList.at(i)) >= 0)
         {
             const QStringList bm_parts(BookmarkList.at(i).split('|'));
             if (bm_parts.count() > 1)
@@ -109,7 +113,7 @@ QList<QAction*> c2bNetworkQueryInfo::bookmarkActions(const QString& selection)
         if (bmd.contains("<<selection>>"))
             if (!_current_selection.isEmpty())
                 bmd.remove("<<selection>>");
-        BookmarkActionList[i]->setVisible(!bmd.contains(rx));
+        BookmarkActionList[i]->setVisible(rx.indexIn(bmd) == -1);
     }
     return BookmarkActionList;
 }
@@ -131,7 +135,7 @@ const QString c2bNetworkQueryInfo::encodeLink(const QString& ln) const
     eln.replace("[[[", "<<");
     eln.replace("]]]", ">>");
     const QRegExp rx("<<.+>>");
-    if (eln.contains(rx))
+    if (rx.indexIn(eln) >= 0)
     {
         const QStringList& bibliographicFields = _bpP->bibliographicFields();
         for (int j = 0; j < bibliographicFields.count(); ++j)
@@ -140,25 +144,19 @@ const QString c2bNetworkQueryInfo::encodeLink(const QString& ln) const
             const QString tag(QString("<<%1>>").arg(name));
             if (eln.contains(tag))
             {
-                QString fld;
+                QString fld(_bpP->field(name));
                 if (name == "pages")
-                    fld = _bpP->field(name).replace(QRegExp("-.+$"), QString());
+                    c2bUtils::replace(fld, QRegExp("-.+$"), QString());
                 else if (name == "author")
-                {
-                    fld = _bpP->field(name);
                     fld.replace(" and ", " ");
-                }
                 else if (name == "title")
                 {
-                    fld = _bpP->field(name);
                     fld = fld.remove('{');
                     fld = fld.remove('}');
                 }
-                else
-                    fld = _bpP->field(name);
                 fld = QUrl::toPercentEncoding(fld);
                 eln.replace(tag, fld);
-                if (!eln.contains(rx))
+                if (rx.indexIn(eln) == -1)
                     return eln;
             }
         }
