@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bReferenceList.h"
@@ -17,6 +17,7 @@
 
 #include <bibSearcher.h>
 
+#include <QActionGroup>
 #include <QHeaderView>
 #include <QMenu>
 #include <QScrollBar>
@@ -173,7 +174,7 @@ c2bReferenceList::c2bReferenceList(c2bTextEdit* ed, c2bTextBrowser* br, QWidget*
     _browserP->setContextMenuPolicy(Qt::ActionsContextMenu);
 
     connect(_browserP, SIGNAL(anchorClicked(QUrl)), this, SLOT(openLink(QUrl)));
-    connect(_browserP, SIGNAL(highlighted(QString)), parentw->parent(), SLOT(showMessage(QString)));
+    connect(_browserP, SIGNAL(highlighted(QUrl)), parentw->parent(), SLOT(showMessage(QUrl)));
 }
 
 c2bReferenceList::~c2bReferenceList() {}
@@ -214,12 +215,12 @@ void c2bReferenceList::loadList(const QString& txt, bibSearcher* searcher)
         {
             author = bpP->authorFromBibTeX(author);
             author_long = author;
-            author_long.remove(nonletters);
+            c2bUtils::remove(author_long, nonletters);
             author_long.replace(" and ", ", ");
             c2bUtils::simplifyString(author_long);
             author_long += '.';
-            author.remove(initials1);
-            author.remove(initials2);
+            c2bUtils::remove(author, initials1);
+            c2bUtils::remove(author, initials2);
             author.replace(" and ", ", ");
             c2bUtils::simplifyString(author);
         }
@@ -385,8 +386,8 @@ void c2bReferenceList::openLink(const QUrl& ln)
     if (ln_str.isEmpty())
         c2b::showMessage(tr("No link available for this reference."));
     else if (ln_str.startsWith("Select reference "))
-        scrollToReference(ln_str.remove(QRegExp("\\D")));
-    else if (ln_str.contains(QRegExp(":\\d+$")))
+        scrollToReference(c2bUtils::removed(ln_str, QRegExp("\\D")));
+    else if (QRegExp(":\\d+$").indexIn(ln_str) >= 0)
         emit openFile(ln_str);
     else
         c2bUtils::openFile(ln_str, parentWidget());
