@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bSearchInFilesPattern.h"
@@ -27,7 +27,7 @@ c2bSearchInFilesPattern::c2bSearchInFilesPattern(QWidget* parentw) : QWidget(par
 
     connect(ui.clearB, SIGNAL(clicked()), this, SLOT(patternChanged()));
     connect(ui.inputPattern, SIGNAL(textEdited(QString)), this, SLOT(patternChanged()));
-    connect(ui.patternScope, SIGNAL(currentIndexChanged(QString)), this, SLOT(showYearScope(QString)));
+    connect(ui.patternScope, SIGNAL(currentTextChanged(QString)), this, SLOT(showYearScope(QString)));
 }
 
 c2bSearchInFilesPattern::~c2bSearchInFilesPattern()
