@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bSettings.h"
@@ -82,6 +82,57 @@ void c2bSettings::setDefaults()
 
     // Shortcuts
     _default_keysequences.clear();
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    _default_keysequences["Shortcuts/cb2Bib/Button About and Bookmarks"] = QKeySequence(Qt::CTRL | Qt::Key_Tab);
+    _default_keysequences["Shortcuts/cb2Bib/Button Configure"] = QKeySequence();
+    _default_keysequences["Shortcuts/cb2Bib/Button Network Query"] = QKeySequence(Qt::ALT | Qt::Key_N);
+    _default_keysequences["Shortcuts/cb2Bib/Button Start PDFImport"] = QKeySequence();
+    _default_keysequences["Shortcuts/cb2Bib/Button Toggle Connection"] = QKeySequence();
+    _default_keysequences["Shortcuts/cb2Bib/Button View BibTeX"] = QKeySequence(Qt::ALT | Qt::Key_V);
+    _default_keysequences["Shortcuts/cb2Bib/Check Repeated"] = QKeySequence(Qt::ALT | Qt::Key_X);
+    _default_keysequences["Shortcuts/cb2Bib/Clear All Fields"] = QKeySequence();
+    _default_keysequences["Shortcuts/cb2Bib/Delete Temporary BibTeX File"] = QKeySequence(Qt::ALT | Qt::Key_D);
+    _default_keysequences["Shortcuts/cb2Bib/Edit Bookmarks"] = QKeySequence(Qt::ALT | Qt::Key_B);
+    _default_keysequences["Shortcuts/cb2Bib/Edit Journal Abbreviations"] = QKeySequence(Qt::ALT | Qt::Key_J);
+    _default_keysequences["Shortcuts/cb2Bib/Edit Regular Expressions"] = QKeySequence(Qt::ALT | Qt::Key_E);
+    _default_keysequences["Shortcuts/cb2Bib/Guess Bibliographic Fields"] = QKeySequence(Qt::ALT | Qt::Key_G);
+    _default_keysequences["Shortcuts/cb2Bib/Insert Regular Expression"] = QKeySequence(Qt::ALT | Qt::Key_I);
+    _default_keysequences["Shortcuts/cb2Bib/Open Document"] = QKeySequence(Qt::ALT | Qt::Key_O);
+    _default_keysequences["Shortcuts/cb2Bib/Postprocess BibTeX"] = QKeySequence(Qt::ALT | Qt::Key_P);
+    _default_keysequences["Shortcuts/cb2Bib/Preparse Clipboard"] = QKeySequence(Qt::ALT | Qt::Key_C);
+    _default_keysequences["Shortcuts/cb2Bib/Restart Recognition"] = QKeySequence(Qt::ALT | Qt::Key_R);
+    _default_keysequences["Shortcuts/cb2Bib/Select BibTeX File"] = QKeySequence(Qt::ALT | Qt::Key_S);
+    _default_keysequences["Shortcuts/cb2Bib/Select Document File"] = QKeySequence(Qt::ALT | Qt::Key_F);
+    _default_keysequences["Shortcuts/cb2Bib/Annote Editor"] = QKeySequence(Qt::ALT | Qt::Key_A);
+    _default_keysequences["Shortcuts/cb2Bib/Toggle Reference Tabs"] = QKeySequence(Qt::Key_F4);
+    _default_keysequences["Shortcuts/cb2Bib/View Tagged Clipboard Data"] = QKeySequence();
+    _default_keysequences["Shortcuts/cb2Bib/Write Metadata to Document"] = QKeySequence(Qt::ALT | Qt::Key_W);
+
+    _default_keysequences["Shortcuts/Editor/Browse Reference by DOI"] = QKeySequence();
+    _default_keysequences["Shortcuts/Editor/Cite Selected Entries"] = QKeySequence(Qt::ALT | Qt::Key_C);
+    _default_keysequences["Shortcuts/Editor/Clear Entry Selection"] = QKeySequence(Qt::Key_Delete);
+    _default_keysequences["Shortcuts/Editor/Export Entries"] = QKeySequence();
+    _default_keysequences["Shortcuts/Editor/Local Search for Selected Text"] = QKeySequence();
+    _default_keysequences["Shortcuts/Editor/Open Document File"] = QKeySequence();
+    _default_keysequences["Shortcuts/Editor/Open Document URL"] = QKeySequence();
+    _default_keysequences["Shortcuts/Editor/Paste Current BibTeX"] = QKeySequence(Qt::SHIFT | Qt::Key_Insert);
+    _default_keysequences["Shortcuts/Editor/Restart Network Query"] = QKeySequence(Qt::ALT | Qt::Key_N);
+    _default_keysequences["Shortcuts/Editor/Restart Recognition"] = QKeySequence(Qt::ALT | Qt::Key_R);
+    _default_keysequences["Shortcuts/Editor/Save and Postprocess"] = QKeySequence(Qt::ALT | Qt::Key_P);
+    _default_keysequences["Shortcuts/Editor/Selection to LaTeX"] = QKeySequence();
+    _default_keysequences["Shortcuts/Editor/Selection to Unicode"] = QKeySequence();
+    _default_keysequences["Shortcuts/Editor/Set Journals to Abbreviated Name"] = QKeySequence();
+    _default_keysequences["Shortcuts/Editor/Set Journals to Full Name"] = QKeySequence();
+    _default_keysequences["Shortcuts/Editor/Set LyX Pipe"] = QKeySequence(Qt::ALT | Qt::Key_L);
+    _default_keysequences["Shortcuts/Editor/Toggle Editing and Browsing"] = QKeySequence(Qt::CTRL | Qt::Key_Tab);
+    _default_keysequences["Shortcuts/Editor/Toggle Word Wrapping"] = QKeySequence();
+    _default_keysequences["Shortcuts/Editor/Update Documents Metadata"] = QKeySequence();
+    _default_keysequences["Shortcuts/Editor/View Note in External Browser"] = QKeySequence();
+    _default_keysequences["Shortcuts/Editor/Web Search Settings"] = QKeySequence();
+    _default_keysequences["Shortcuts/Editor/Web Search by Author"] = QKeySequence();
+    _default_keysequences["Shortcuts/Editor/Web Search by Title"] = QKeySequence();
+    _default_keysequences["Shortcuts/Editor/Web Search for Selected Text"] = QKeySequence();
+#else
     _default_keysequences["Shortcuts/cb2Bib/Button About and Bookmarks"] = QKeySequence(Qt::CTRL + Qt::Key_Tab);
     _default_keysequences["Shortcuts/cb2Bib/Button Configure"] = QKeySequence();
     _default_keysequences["Shortcuts/cb2Bib/Button Network Query"] = QKeySequence(Qt::ALT + Qt::Key_N);
@@ -131,7 +182,7 @@ void c2bSettings::setDefaults()
     _default_keysequences["Shortcuts/Editor/Web Search by Author"] = QKeySequence();
     _default_keysequences["Shortcuts/Editor/Web Search by Title"] = QKeySequence();
     _default_keysequences["Shortcuts/Editor/Web Search for Selected Text"] = QKeySequence();
-
+#endif
     const QStringList sc(_default_keysequences.keys());
     for (int i = 0; i < sc.count(); ++i)
         setValue(sc.at(i), value(sc.at(i), _default_keysequences.value(sc.at(i))));
