@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bShortcutWidget.h"
@@ -42,7 +42,7 @@ void c2bShortcutWidget::setShortcutNames(const QString& path, const QStringList&
 {
     disconnect(ui.Shortcut, SIGNAL(shortcutChanged(QKeySequence,QKeySequence)), this,
                SLOT(shortcutChanged(QKeySequence,QKeySequence)));
-    disconnect(ui.Description, SIGNAL(currentIndexChanged(QString)), this, SLOT(currentIndexChanged(QString)));
+    disconnect(ui.Description, SIGNAL(currentTextChanged(QString)), this, SLOT(currentTextChanged(QString)));
     _modified_keysequences.clear();
 
     _shortcut_path = path;
@@ -58,12 +58,12 @@ void c2bShortcutWidget::setShortcutNames(const QString& path, const QStringList&
 
     connect(ui.Shortcut, SIGNAL(shortcutChanged(QKeySequence,QKeySequence)), this,
             SLOT(shortcutChanged(QKeySequence,QKeySequence)));
-    connect(ui.Description, SIGNAL(currentIndexChanged(QString)), this, SLOT(currentIndexChanged(QString)));
+    connect(ui.Description, SIGNAL(currentTextChanged(QString)), this, SLOT(currentTextChanged(QString)));
 }
 
-void c2bShortcutWidget::currentIndexChanged(const QString& name)
+void c2bShortcutWidget::currentTextChanged(const QString& text)
 {
-    const QString fullname(_shortcut_path + name);
+    const QString fullname(_shortcut_path + text);
     if (_modified_keysequences.contains(fullname))
         ui.Shortcut->setKeysequence(_modified_keysequences.value(fullname));
     else
