@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BSHORTCUTWIDGET_H
@@ -38,7 +38,7 @@ signals:
 
 
 private slots:
-    void currentIndexChanged(const QString& name);
+    void currentTextChanged(const QString& text);
     void shortcutChanged(const QKeySequence& oldks, const QKeySequence& newks);
 
 
