@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #define C2B_CHECK_CAPITALIZATION 0
@@ -19,14 +19,19 @@
 
 #include <QCoreApplication>
 #include <QDataStream>
+#include <QLibraryInfo>
+#include <QRegularExpression>
 #include <QSysInfo>
 #include <QTextStream>
 
 
 c2bTests::c2bTests() : cout(*(new QTextStream(stdout))), _failed_test_count(0), _test_count(0)
 {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    cout.setEncoding(QStringConverter::Utf8);
+#else
     cout.setCodec("UTF-8");
-
+#endif
     cout << "============" << _QT_6_endl;
     cout << "cb2Bib tests" << _QT_6_endl;
     cout << "============" << _QT_6_endl;
@@ -48,10 +53,12 @@ int c2bTests::allTests()
     _test_count = 0;
     _failed_test_count = 0;
 #if C2B_CHECK_PATTERNS
+#warning[cb2Bib] C2B_CHECK_PATTERNS should be disabled in production builds
     heuristic_check_patterns();
     return 0;
 #endif
 #if C2B_CHECK_JOURNALS
+#warning[cb2Bib] C2B_CHECK_JOURNALS should be disabled in production builds
     check_abbreviations_txt();
     heuristic_journal();
 #else
@@ -59,7 +66,9 @@ int c2bTests::allTests()
     heuristic_pvny();
     heuristic_misc();
     heuristic_author();
+#if C2B_CHECK_PDF_AUTHORS
     heuristic_check_patterns();
+#endif
     compression_check();
     write_information();
 #endif
@@ -186,6 +195,7 @@ void c2bTests::write_information()
 #endif
     cout << "\n-------------------------" << _QT_6_endl;
     cout << "OS:" << _QT_6_endl;
+    cout << "-------------------------" << _QT_6_endl;
     cout << "Build CPU:       " << QSysInfo::buildCpuArchitecture() << _QT_6_endl;
     cout << "CPU:             " << QSysInfo::currentCpuArchitecture() << _QT_6_endl;
     cout << "Kernel Type:     " << QSysInfo::kernelType() << _QT_6_endl;
@@ -194,6 +204,9 @@ void c2bTests::write_information()
     cout << "Product Version: " << QSysInfo::productVersion() << '|' << int(QSysInfo::productVersion().toDouble()) << _QT_6_endl;
     cout << "Name:            " << QSysInfo::prettyProductName() << _QT_6_endl;
     cout << "-------------------------" << _QT_6_endl;
+    cout << "Qt version:      " << QLibraryInfo::version().toString() << _QT_6_endl;
+    cout << "Build ABI:       " << QSysInfo::buildAbi() << _QT_6_endl;
+    cout << "-------------------------" << _QT_6_endl;
     cout << _QT_6_endl;
 }
 
@@ -213,6 +226,7 @@ void c2bTests::heuristic_author()
     bp.initReferenceParsing(_bibliographic_dir, fields, &reference);
 
 #if C2B_CHECK_CAPITALIZATION
+#warning[cb2Bib] C2B_CHECK_CAPITALIZATION should be disabled in production builds
     for (int f = 0; f < flist.count(); ++f)
     {
         const QString bib_file(flist.at(f).absoluteFilePath());
@@ -238,6 +252,7 @@ void c2bTests::heuristic_author()
     return;
 #endif
 #if C2B_CHECK_CODE_DECOMPOSITION
+#warning[cb2Bib] C2B_CHECK_CODE_DECOMPOSITION should be disabled in production builds
     for (int u = 1; u < 78790; ++u)
     {
         const QChar c(u);
@@ -255,6 +270,7 @@ void c2bTests::heuristic_author()
     return;
 #endif
 #if C2B_CHECK_PDF_CODES
+#warning[cb2Bib] C2B_CHECK_PDF_CODES should be disabled in production builds
     QMap<QChar, long long> charfreq;
     long long char_count = 0;
     for (int f = 0; f < flist.count(); ++f)
@@ -266,7 +282,7 @@ void c2bTests::heuristic_author()
         while (bp.referencesIn(c2bUtils::fileToString(bib_file), &reference))
         {
             const QString file(reference.value("file"));
-            document d(file, document::Raw);
+            document d(file, document::Complete);
             const QString doc(d.toString());
             for (int i = 0; i < doc.length(); ++i)
             {
@@ -289,6 +305,7 @@ void c2bTests::heuristic_author()
     return;
 #endif
 #if C2B_CHECK_PDF_AUTHORS
+#warning[cb2Bib] C2B_CHECK_PDF_AUTHORS should be disabled in production builds
     cout << _QT_6_endl;
     cout << "----------------------------------------" << _QT_6_endl;
     cout << "Test heuristic author recognition on PDF" << _QT_6_endl;
@@ -297,14 +314,18 @@ void c2bTests::heuristic_author()
     cout << "Checking files at: " << _bibliographic_dir << _QT_6_endl;
 
     const QStringList excluded(c2bUtils::fileToString(_bibliographic_dir + "/c2b_test_exclude.txt")
-                               .split(QRegExp("[\\n\\r]"), _QT_6_SkipEmptyParts));
+                               .split(QRegularExpression("[\\n\\r]"), _QT_6_SkipEmptyParts));
     QHash<QString, QString> doc_cache;
     const QString doc_cache_fn(_bibliographic_dir + "/c2b_test.cache");
     if (QFileInfo::exists(doc_cache_fn))
     {
         cout << "Reading from cache" << _QT_6_endl;
         QFile file(doc_cache_fn);
-        file.open(QIODevice::ReadOnly);
+        if (!file.open(QIODevice::ReadOnly))
+        {
+            cout << "Failed opening test file." << _QT_6_endl;
+            return;
+        }
         QDataStream ds(&file);
         ds >> doc_cache;
     }
@@ -329,7 +350,11 @@ void c2bTests::heuristic_author()
         if (doc_cache.size() > 0)
         {
             QFile file(doc_cache_fn);
-            file.open(QIODevice::WriteOnly);
+            if (!file.open(QIODevice::WriteOnly))
+            {
+                cout << "Failed opening cache test file." << _QT_6_endl;
+                return;
+            }
             QDataStream ds(&file);
             ds << doc_cache;
             cout << "Writing cache " << doc_cache_fn << _QT_6_endl;
@@ -354,7 +379,7 @@ void c2bTests::heuristic_author()
                 continue;
             const QString doc(doc_cache.value(reference.value("file")));
             QString check_doc(doc);
-            check_doc.remove(c2bUtils::nonAsciiLetter);
+            c2bUtils::remove(check_doc, c2bUtils::nonAsciiLetter);
             if (check_doc.isEmpty())
                 continue;
 
@@ -418,7 +443,11 @@ void c2bTests::check_abbreviations_txt()
         if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
             return;
         QTextStream stream(&file);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        stream.setEncoding(QStringConverter::Utf8);
+#else
         stream.setCodec("UTF-8");
+#endif
         stream.setAutoDetectUnicode(true);
         QString line;
         int line_number(0);
@@ -458,27 +487,27 @@ void c2bTests::check_abbreviations_txt()
         const int njournals(code.count());
         QStringList counter;
         for (int i = 0; i < njournals; ++i)
-            counter += code.at(i).toLower().remove(c2bUtils::nonLetter);
+            counter += c2bUtils::removed(code.at(i).toLower(), c2bUtils::nonLetter);
         counter.removeDuplicates();
         cout << "code total:  " << njournals << " unique: " << counter.count() << _QT_6_endl;
         counter.clear();
         for (int i = 0; i < njournals; ++i)
-            counter += abbr1.at(i).toLower().remove(c2bUtils::nonLetter);
+            counter += c2bUtils::removed(abbr1.at(i).toLower(), c2bUtils::nonLetter);
         counter.removeDuplicates();
         cout << "abbr1 total: " << njournals << " unique: " << counter.count() << _QT_6_endl;
         counter.clear();
         for (int i = 0; i < njournals; ++i)
-            counter += full1.at(i).toLower().remove(c2bUtils::nonLetter);
+            counter += c2bUtils::removed(full1.at(i).toLower(), c2bUtils::nonLetter);
         counter.removeDuplicates();
         cout << "full1 total: " << njournals << " unique: " << counter.count() << _QT_6_endl;
         counter.clear();
         for (int i = 0; i < njournals; ++i)
-            counter += abbr2.at(i).toLower().remove(c2bUtils::nonLetter);
+            counter += c2bUtils::removed(abbr2.at(i).toLower(), c2bUtils::nonLetter);
         counter.removeDuplicates();
         cout << "abbr2 total: " << njournals << " unique: " << counter.count() << _QT_6_endl;
         counter.clear();
         for (int i = 0; i < njournals; ++i)
-            counter += full2.at(i).toLower().remove(c2bUtils::nonLetter);
+            counter += c2bUtils::removed(full2.at(i).toLower(), c2bUtils::nonLetter);
         counter.removeDuplicates();
         cout << "full2 total: " << njournals << " unique: " << counter.count() << _QT_6_endl;
     }
@@ -594,7 +623,7 @@ void c2bTests::heuristic_journal()
     fields.append("file");
 
     const QStringList excluded(c2bUtils::fileToString(_bibliographic_dir + "/c2b_test_exclude.txt")
-                               .split(QRegExp("[\\n\\r]"), _QT_6_SkipEmptyParts));
+                               .split(QRegularExpression("[\\n\\r]"), _QT_6_SkipEmptyParts));
     QHash<QString, QString> doc_cache;
     const QString doc_cache_fn(_bibliographic_dir + "/c2b_test.cache");
     if (QFileInfo(doc_cache_fn).exists())
@@ -627,8 +656,7 @@ void c2bTests::heuristic_journal()
             if (excluded.contains(file) || file.contains("/stacks/"))
                 continue;
             const QString doc(doc_cache.value(file));
-            QString check_doc(doc);
-            check_doc.remove(c2bUtils::nonAsciiLetter);
+            const QString check_doc(c2bUtils::removed(doc, c2bUtils::nonAsciiLetter));
             if (check_doc.isEmpty())
                 continue;
             doclengths.append(check_doc.length());
@@ -1216,13 +1244,13 @@ void c2bTests::heuristic_check_patterns()
         while (bp.referencesIn(c2bUtils::fileToString(bib_file), &reference))
         {
             const QString a(c2bUtils::toAscii(reference.value("author"), c2bUtils::Collation));
-            const QStringList as(a.split(c2bUtils::nonLetter));
+            const QStringList as(c2bUtils::split(a, c2bUtils::nonLetter, _QT_6_KeepEmptyParts));
             for (int i = 0; i < as.count(); ++i)
                 adictionary.insert(as.at(i), 1 + adictionary.value(as.at(i), 0));
         }
     }
-    QStringList word_prefix_lexicon(
-        c2bUtils::fileToString(":/txt/txt/word_prefix_lexicon.txt").split(c2bUtils::nonLetter, _QT_6_SkipEmptyParts));
+    QStringList word_prefix_lexicon(c2bUtils::split(c2bUtils::fileToString(":/txt/txt/word_prefix_lexicon.txt"),
+                                    c2bUtils::nonLetter, _QT_6_SkipEmptyParts));
     for (int i = 0; i < word_prefix_lexicon.count(); ++i)
         word_prefix_lexicon[i].replace('_', "\\b");
 
@@ -1234,7 +1262,7 @@ void c2bTests::heuristic_check_patterns()
             const QString& wp = word_prefix_lexicon.at(i);
             const QString& a = anames.at(j);
             wre.setPattern(wp);
-            if (a.contains(wre))
+            if (wre.indexIn(a) >= 0)
                 cout << "LEXICON CLASH: " << wp << ' ' << a << _QT_6_endl;
         }
 }
