@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bTextBrowser.h"
@@ -16,12 +16,15 @@ c2bTextBrowser::c2bTextBrowser(QWidget* parentw) : QTextBrowser(parentw)
 {
     setFrameShape(QTextBrowser::StyledPanel);
     setFrameShadow(QTextBrowser::Raised);
+    setOpenLinks(false);
 }
 
 c2bTextBrowser::~c2bTextBrowser() {}
 
 
-void c2bTextBrowser::setSource(const QUrl& /* dummy_name */) {}
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+void c2bTextBrowser::setSource(const QUrl& /* url */) {}
+#endif
 
 void c2bTextBrowser::contextMenuEvent(QContextMenuEvent* qevent)
 {
