@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BTEXTBROWSER_H
@@ -28,8 +28,9 @@ public:
 
 
 public slots:
-    virtual void setSource(const QUrl& name);
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    void setSource(const QUrl& url) override;
+#endif
 
 protected:
     virtual void contextMenuEvent(QContextMenuEvent* qevent);
