@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BUTILS_H
@@ -14,6 +14,7 @@
 #include <QAction>
 #include <QTextDocument>
 #include <QUrl>
+#include <QWidget>
 
 /**
     General cb2Bib Utils: GUI related utilities
@@ -57,7 +58,7 @@ inline QString fromHtmlString(const QString& str, const bool addMetadata = false
 inline void addSeparator(QWidget* w)
 {
     // Adds separator to widget w
-    QAction* action = new QAction(w);
+    QAction* action = new QAction(reinterpret_cast<QObject*>(w));
     action->setSeparator(true);
     w->addAction(action);
 }
