@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef CB2BIB_H
@@ -103,7 +103,7 @@ private slots:
     void forceDataChange(const QString& str);
     void guessFields();
     void insertRegExp();
-    void linkClicked(const QUrl& ln);
+    void linkClicked(const QUrl& link);
     void loadSettings();
     void makeNetQuery();
     void netQueryEnded(bool succeeded, const QString& targetPDF, const QString& targetBib);
@@ -130,7 +130,7 @@ private slots:
     void setDocumentFilename();
     void setTaggedClipEditMode(bool tagged);
     void setWindowTitle();
-    void showLink(const QString& ln);
+    void showLink(const QUrl& link);
     void showMessage(const QString& ms);
     void toggleReferenceTabs();
     void updateCheckRepeatedAction();
