@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2024 by Pere Constans
+ *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "qtsingleapplication/src/qtsingleapplication.h"
@@ -29,7 +29,8 @@ int main(int argc, char* argv[])
     {
         // Cannot use QCoreApplication, QTextDocument is required by c2bUtils::fromHtmlString
         // Needs also workaround c2bSettings::decodeFilename()
-        QApplication app(argc, argv);
+        qDebug()<<"QCoreApplication";
+        QCoreApplication app(argc, argv);
         app.setOrganizationName(C2B_ORGANIZATION);
         app.setApplicationName(C2B_APPLICATION);
         c2b_settings = c2bSettings::initSettings();
